import 'package:flutter_facebook_login/flutter_facebook_login.dart';
import 'package:onyva_mobile/business/authentication_business.dart';
import 'package:onyva_mobile/core/business/implementation/abstract_business_impl.dart';
import 'package:onyva_mobile/core/exceptions/remote_repository_exception.dart';
import 'package:onyva_mobile/core/utils/functions.dart';
import 'package:onyva_mobile/core/utils/preferences.dart';
import 'package:onyva_mobile/models/enums/login_type.dart';
import 'package:onyva_mobile/models/owner.dart';
import 'package:onyva_mobile/repositories/authentication_repository.dart';
import 'package:onyva_mobile/repositories/impl/authentication_repository_imp.dart';

class AuthenticationBusinessImpl extends AbstractBusinessImpl
    implements AuthenticationBusiness {
  final AuthenticationRepository _remoteRepository =
      AuthenticationRepositoryImpl();

  @override
  Future<Owner> authenticateUser(
    LoginType loginType, {
    String email,
    String password,
  }) async {
    try {
      if (loginType == LoginType.FACEBOOK) {
        final facebookLogin = FacebookLogin();
        final result = await facebookLogin.logIn(['email']);

        switch (result.status) {
          case FacebookLoginStatus.loggedIn:
            final token = result.accessToken.token;
            final graphResponse = await _remoteRepository
                .getUserDataFromFacebookByToken('$token');

            final owner = Owner.fromJson(graphResponse);
            saveLoggedOwner(owner);
            return owner;
            break;
          case FacebookLoginStatus.cancelledByUser:
            return Future.error('');

            break;
          case FacebookLoginStatus.error:
            return Future.error('Ocorreu um erro durante a autenticação.');
            break;
        }
      } else {
        Map<String, dynamic> response =
            await _remoteRepository.authenticate(email, password);

        final owner = Owner.fromJson(response);
        saveLoggedOwner(owner);

        return owner;
      }
    } on RemoteRepositoryException catch (e) {
      return Future.error(translateMessageFromRemoteRepositoryException(e));
    }
    return null;
  }

  @override
  Future<bool> isAlreadyAuthenticated() async {
    Owner owner = await loadLoggedOwner();

    return owner != null;
  }

  @override
  Future<bool> logouUser() async {
    return Preferences.removeString(Preferences.LOGGED_USER_DATA);
  }
}
