import 'package:onyva_mobile/business/repair_shop_business.dart';
import 'package:onyva_mobile/core/business/implementation/abstract_business_impl.dart';
import 'package:onyva_mobile/core/exceptions/remote_repository_exception.dart';
import 'package:onyva_mobile/models/scheduled_maintenance.dart';
import 'package:onyva_mobile/models/repair_shop_calendar.dart';
import 'package:onyva_mobile/models/repair_shop.dart';
import 'package:onyva_mobile/repositories/impl/repair_shop_repository_impl.dart';
import 'package:onyva_mobile/repositories/impl/maintenance_repository_impl.dart';
import 'package:onyva_mobile/repositories/repair_shop_repository.dart';
import 'package:onyva_mobile/repositories/maintenance_repository.dart';

class RepairShopBusinessImpl extends AbstractBusinessImpl
    implements RepairShopBusiness {
  RepairShopRepository repairShopRepository = new RepairShopRepositoryImpl();
  MaintenanceRepository maintenanceRepository = new MaintenanceRepositoryImpl();

  @override
  Future<List<String>> getServicesByBrandModel(
      String brand, String model) async {
    try {
      List<dynamic> response = await maintenanceRepository
          .getScheduledMaintenancesByBrandModel(brand, model);

      if (response == null) {
        return Future.error(
            'Erro ao cadastrar a manutenção programada. Tente novamente mais tarde.');
      }

      List<ScheduledMaintenance> sms = response
          .map((smJson) => ScheduledMaintenance.fromJson(smJson))
          .toList();

      Set<String> services = new Set();

      sms.forEach((sm) {
        sm.inspectionItems.split(';').forEach((item) {
          services.add(item);
        });
        sm.replaceItems.split(';').forEach((item) {
          services.add(item);
        });
      });

      return services.toList();
    } on RemoteRepositoryException catch (e) {
      return Future.error(translateMessageFromRemoteRepositoryException(e));
    }
  }

  @override
  Future<List<RepairShopCalendarEvent>> getRepairShopCalendarById(
    int repairShopId,
  ) async {
    try {
      final calendar =
          await repairShopRepository.getRepairShopCalendar(repairShopId);

      return calendar
          .map(
            (calendarEventJson) =>
                RepairShopCalendarEvent.fromJson(calendarEventJson),
          )
          .toList();
    } on RemoteRepositoryException catch (e) {
      return Future.error(translateMessageFromRemoteRepositoryException(e));
    }
  }

  @override
  Future<List<RepairShop>> getRepairShops(List<String> services) async {
    try {
      List<dynamic> response =
          await repairShopRepository.getRepairShops(services);

      if (response == null) {
        return Future.error(
            'Erro ao requisitar as oficinas. Tente novamente mais tarde.');
      }

      List<RepairShop> repairShops = response.map((repairShopJson) {
        repairShopJson['specialities'] = repairShopJson['specialties'];
        return RepairShop.fromJson(repairShopJson);
      }).toList();

      return repairShops;
    } on RemoteRepositoryException catch (e) {
      return Future.error(translateMessageFromRemoteRepositoryException(e));
    }
  }
}
