import 'package:onyva_mobile/business/implementation/repair_shop_business_impl.dart';
import 'package:onyva_mobile/business/repair_shop_business.dart';
import 'package:onyva_mobile/business/scheduled_maintenance_business.dart';
import 'package:onyva_mobile/core/business/implementation/abstract_business_impl.dart';
import 'package:onyva_mobile/core/exceptions/remote_repository_exception.dart';
import 'package:onyva_mobile/core/utils/functions.dart';
import 'package:onyva_mobile/models/maintenance_scheduling.dart';
import 'package:onyva_mobile/models/repair_shop.dart';
import 'package:onyva_mobile/models/requested_maintenance.dart';
import 'package:onyva_mobile/models/scheduled_maintenance.dart';
import 'package:onyva_mobile/repositories/impl/maintenance_repository_impl.dart';
import 'package:onyva_mobile/repositories/maintenance_repository.dart';

class ScheduledMaintenanceBusinessImpl extends AbstractBusinessImpl
    implements ScheduledMaintenanceBusiness {
  MaintenanceRepository maintenanceRepository = new MaintenanceRepositoryImpl();
  RepairShopBusiness repairShopBusiness = RepairShopBusinessImpl();

  @override
  Future<MaintenanceScheduling> schedule(
    String ownerId,
    String vehicleId,
    String repairShopId,
    DateTime scheduleDateTime,
    String maintenanceTitle,
    ManutentionType manutentionType, {
    String scheduledMaintenanceId,
  }) async {
    try {
      return await maintenanceRepository
          .scheduleMaintenance(MaintenanceScheduling(
        maintenanceDescription: maintenanceTitle,
        owner: ownerId,
        vehicle: vehicleId,
        maintenanceType: getCodeOfMaintenanceType(manutentionType),
        repairShop: RepairShop(id: repairShopId),
        scheduledMaintenance: ScheduledMaintenance(id: scheduledMaintenanceId),
        date: scheduleDateTime,
      ));
    } on RemoteRepositoryException catch (e) {
      return Future.error(translateMessageFromRemoteRepositoryException(e));
    }
  }

  @override
  Future<List<ScheduledMaintenance>>
      getScheduledMaintenancesServicesByBrandModel(
    String brand,
    String model,
  ) async {
    try {
      List<dynamic> response = await maintenanceRepository
          .getScheduledMaintenancesByBrandModel(brand, model);

      if (response == null) {
        return Future.error(
            'Erro ao cadastrar a manutenção programada. Tente novamente mais tarde.');
      }

      List<ScheduledMaintenance> sms = response
          .map((smJson) => ScheduledMaintenance.fromJson(smJson))
          .toList();

      return sms;
    } on RemoteRepositoryException catch (e) {
      return Future.error(translateMessageFromRemoteRepositoryException(e));
    }
  }

  @override
  Future<MaintenanceScheduling> getScheduledMaintenanceRequestPendingApproval(
    String ownerId,
  ) {
    return this
        .maintenanceRepository
        .getScheduledMaintenanceRequestPendingApproval(ownerId);
  }
}
