import 'package:onyva_mobile/core/business/abstract_business.dart';
import 'package:onyva_mobile/core/exceptions/remote_repository_exception.dart';
import 'package:onyva_mobile/core/models/repositories/remote/remote_repository_exception_type.dart';

abstract class AbstractBusinessImpl implements AbstractBusiness {
  static const _SERVER_UNAVAILABLE_DEFAULT_MESSAGE =
      'Desculpe, mas tivemos um problema durante a sua solicitação. Tente novamente dentro de alguns segundos.';

  static const _NO_INTERNET_CONNECTION_DEFAULT_MESSAGE =
      'Você não está conectado à internet. Por favor, verifique a sua conexão e tente novamente.';

  static const _UNAUTHORIZED_DEFAULT_MESSAGE =
      'Você não está autenticado. Por favor realize novamente o login.';

  @override
  String translateMessageFromRemoteRepositoryException(
    RemoteRepositoryException e,
  ) {
    switch (e.remoteRepositoryExceptionType) {
      case RemoteRepositoryExceptionType.NO_INTERNET_CONNECTION:
        return _NO_INTERNET_CONNECTION_DEFAULT_MESSAGE;

      case RemoteRepositoryExceptionType.BAD_REQUEST:
        return e.originalMessage;

      case RemoteRepositoryExceptionType.UNAUTHORIZED:
        return _UNAUTHORIZED_DEFAULT_MESSAGE;

      default:
        return _SERVER_UNAVAILABLE_DEFAULT_MESSAGE;
    }
  }
}
