import 'package:flutter/material.dart';
import 'package:onyva_mobile/core/widgets/color_sets.dart';

generalInformationAlert(
    {@required BuildContext context,
    @required String title,
    @required Widget body,
    @required String okText,
    bool enableDismissButton = false,
    String dismissButtonText,
    Function(bool) callbackFunction,
    Icon icon}) {
  callbackFunction != null
      ? showDialog<bool>(
          context: context,
          barrierDismissible: false,
          builder: (context) {
            return _showDialogBody(
                context: context,
                title: title,
                body: body,
                okText: okText,
                enableDismissButton: enableDismissButton,
                dismissButtonText: dismissButtonText,
                icon: icon);
          },
        ).then(callbackFunction)
      : showDialog<bool>(
          context: context,
          barrierDismissible: false,
          builder: (context) {
            return _showDialogBody(
                context: context,
                title: title,
                body: body,
                okText: okText,
                enableDismissButton: enableDismissButton,
                dismissButtonText: dismissButtonText,
                icon: icon);
          },
        );
}

_showDialogBody(
    {@required BuildContext context,
    @required String title,
    @required Widget body,
    @required String okText,
    bool enableDismissButton = false,
    String dismissButtonText,
    Icon icon}) {
  final screenSize = MediaQuery.of(context).size;
  final screenWidth = screenSize.width;

  return WillPopScope(
    onWillPop: () async => false,
    child: AlertDialog(
      title: Container(
        width: screenWidth - 300,
        child: Row(
          children: <Widget>[
            icon != null
                ? icon
                : Icon(
                    Icons.error_outline,
                    color: Colors.red,
                  ),
            Padding(
              padding: EdgeInsets.only(
                right: 10,
              ),
            ),
            Flexible(
              child: Text(title),
            )
          ],
        ),
      ),
      content: body,
      actions: <Widget>[
        enableDismissButton
            ? FlatButton(
                child: Text(dismissButtonText),
                onPressed: () {
                  Navigator.pop(context, false);
                },
                textColor: ColorSets.darkBlue,
              )
            : Container(),
        FlatButton(
          child: Text(okText),
          onPressed: () {
            Navigator.pop(context, true);
          },
          textColor: ColorSets.darkBlue,
        )
      ],
    ),
  );
}
