import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:onyva_mobile/core/utils/preferences.dart';
import 'package:onyva_mobile/models/enums/maintenance.dart';
import 'package:onyva_mobile/models/owner.dart';
import 'package:onyva_mobile/models/requested_maintenance.dart';
import 'package:onyva_mobile/models/vehicle.dart';

void popUntil(BuildContext context, String route) =>
    Navigator.of(context).popUntil(ModalRoute.withName(route));

void pushNamedAndRemoveUntil(BuildContext context, String route) =>
    Navigator.of(context).pushNamedAndRemoveUntil(
      route,
      (Route<dynamic> route) => false,
    );

Future<dynamic> pushNamed(BuildContext context, String route) async =>
    await Navigator.of(context).pushNamed(
      route,
    );

Future<dynamic> pushNamedWithArguments(
        BuildContext context, String route, dynamic arguments) async =>
    await Navigator.of(context).pushNamed(route, arguments: arguments);

Future<void> delayAction() {
  return Future.delayed(
    Duration(milliseconds: 300),
  );
}

void saveLoggedOwner(Owner loggedOwner) async {
  if (loggedOwner == null) return;
  Preferences.setString(
    Preferences.LOGGED_USER_DATA,
    json.encode(loggedOwner.toJson()),
  );
}

Future<Owner> loadLoggedOwner() async {
  try {
    String str = await Preferences.getString(
      Preferences.LOGGED_USER_DATA,
    );
    Owner owner = Owner.fromJson(json.decode(str) as Map);
    return owner;
  } catch (exc) {
    print('Error on load logged owner ' + exc.toString());
    return null;
  }
}

List<Vehicle> mergeVehicleList(
    List<Vehicle> vehicles, List<Vehicle> newVehicles) {
  List<Vehicle> aux = [];
  if (vehicles == null || vehicles.length == 0) return newVehicles;
  if (newVehicles == null) return vehicles;
  if (newVehicles.length == 0) return [];

  for (Vehicle v2 in newVehicles) {
    Vehicle found =
        vehicles.firstWhere((v) => v.id == v2.id, orElse: () => null);
    if (found != null) {
      aux.add(found.patch(v2));
    } else {
      aux.add(v2);
    }
  }
  return aux;
}

List<RequestedMaintenance> mergeRequestedMaintenanceList(
    List<RequestedMaintenance> req, List<RequestedMaintenance> newReq) {
  List<RequestedMaintenance> aux = [];
  if (req == null || req.length == 0) return newReq;
  if (newReq == null) return req;
  if (newReq.length == 0) return [];

  for (RequestedMaintenance v2 in newReq) {
    RequestedMaintenance found =
        req.firstWhere((v) => v.id == v2.id, orElse: () => null);
    if (found != null) {
      aux.add(found.patch(v2));
    } else {
      aux.add(v2);
    }
  }
  return aux;
}

Map<String, dynamic> extractDDDAndNumber(String phone) {
  RegExp regExp =
      new RegExp(r"^\({0,1}(\d{1,3})\){0,1}\ {0,1}(\d{4,5}\-{0,1}\d{4})$");
  List<RegExpMatch> matches = regExp.allMatches(phone).toList();
  if (matches.length > 0 && matches[0].groupCount == 2) {
    RegExpMatch first = matches[0];

    int ddd = int.parse(first.group(1));
    int number = int.parse(first.group(2).replaceAll('-', ''));

    Map<String, dynamic> extracted = new Map();
    extracted['ddd'] = ddd;
    extracted['number'] = number;

    return extracted;
  } else {
    return null;
  }
}

String getNameOfManutentionType(ManutentionType mType) {
  switch (mType) {
    case ManutentionType.PREVENTIVE:
      return "Manutenção Preventiva";
    case ManutentionType.SCHEDULED:
      return "Manutenção Programada";
    case ManutentionType.URGENT:
      return "Manutenção Urgente";
    case ManutentionType.ALL:
      return "Manutenção";
  }
  return "";
}

String getCodeOfMaintenanceType(ManutentionType mType) {
  switch (mType) {
    case ManutentionType.PREVENTIVE:
      return "UM";
    case ManutentionType.SCHEDULED:
      return "SM";
    case ManutentionType.URGENT:
      return "EM";
    default:
      return null;
  }
}

String getNameOfManutentionType2(MaintenanceTypesEnum mType) {
  switch (mType) {
    case MaintenanceTypesEnum.SM:
      return "Manutenção Programada";
    case MaintenanceTypesEnum.EM:
      return "Manutenção de Emergência";
    case MaintenanceTypesEnum.UM:
      return "Manutenção Preventiva";
  }
  return "";
}

String getNameOfManutentionStatus(MaintenanceStatusEnum mType) {
  switch (mType) {
    case MaintenanceStatusEnum.AC:
      return "Aceita";
    case MaintenanceStatusEnum.CO:
      return "Completa";
    case MaintenanceStatusEnum.DE:
      return "Negada";
    case MaintenanceStatusEnum.EX:
      return "Expirada";
    case MaintenanceStatusEnum.SE:
      return "Enviada";
  }
  return "";
}
