import 'package:auto_size_text/auto_size_text.dart';
import 'package:flutter/material.dart';
import 'package:intl/intl.dart';

class DateTimePicker extends StatefulWidget {
  final double height;
  final Color textColor;
  final Color backgroundColor;
  final DateTime firstDateTime;
  final DateTime lastDateTime;
  final Function onChange;
  final bool Function(DateTime day) enableDay;
  DateTime currentDateTime;

  DateTimePicker({
    this.height,
    this.textColor,
    this.backgroundColor,
    this.currentDateTime,
    this.firstDateTime,
    this.lastDateTime,
    this.onChange,
    this.enableDay,
  });

  @override
  _DateTimePickerState createState() => _DateTimePickerState();
}

class _DateTimePickerState extends State<DateTimePicker> {
  String getText() {
    final DateFormat dateFormatter = DateFormat('dd/MM/yyyy');
    final String formatted = dateFormatter.format(widget.currentDateTime) +
        " às " +
        widget.currentDateTime.hour.toString() +
        ":" +
        widget.currentDateTime.minute.toString() +
        " Horas";

    return formatted;
  }

  void setCurrentDate(DateTime date) {
    widget.currentDateTime = new DateTime(
      date.year,
      date.month,
      date.day,
      widget.currentDateTime.hour,
      widget.currentDateTime.minute,
    );
    dispareOnChange();
  }

  void setCurrentTimeOfDay(TimeOfDay tod) {
    widget.currentDateTime = new DateTime(
        widget.currentDateTime.year,
        widget.currentDateTime.month,
        widget.currentDateTime.day,
        tod.hour,
        tod.minute);
    dispareOnChange();
  }

  TimeOfDay getCurrentTimeOfDay() {
    return new TimeOfDay(
      hour: widget.currentDateTime.hour,
      minute: widget.currentDateTime.minute,
    );
  }

  void dispareOnChange() {
    DateTime result = DateTime(
      widget.currentDateTime.year,
      widget.currentDateTime.month,
      widget.currentDateTime.day,
      widget.currentDateTime.hour,
      widget.currentDateTime.minute,
    );
    widget.onChange(result);
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      alignment: Alignment.centerLeft,
      margin: EdgeInsets.only(left: 30),
      child: GestureDetector(
          onTap: () {
            showDatePicker(
              context: context,
              initialDate: widget.currentDateTime,
              firstDate: widget.firstDateTime,
              lastDate: widget.lastDateTime,
              selectableDayPredicate: widget.enableDay,
            ).then((date) {
              if (date == null) {
                return;
              }
              setCurrentDate(date);

              showTimePicker(
                context: context,
                initialTime: getCurrentTimeOfDay(),
              ).then((time) {
                if (date == null) {
                  Navigator.pop(context);
                  return;
                }
                setCurrentTimeOfDay(time);
              });
            });
          },
          child: Container(
            width: 200,
            alignment: Alignment.centerLeft,
            decoration: BoxDecoration(
              color: widget.backgroundColor,
              borderRadius: BorderRadius.all(
                Radius.circular(widget.height),
              ),
            ),
            height: widget.height,
            child: Padding(
              padding: EdgeInsets.symmetric(horizontal: 10, vertical: 10),
              child: AutoSizeText(
                getText(),
                maxLines: 1,
                style: TextStyle(
                  color: widget.textColor,
                  fontSize: 40,
                  fontWeight: FontWeight.bold,
                ),
              ),
            ),
          )),
    );
  }
}
