import 'package:email_validator/email_validator.dart';
import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:intl/intl.dart';
import 'package:onyva_mobile/core/utils/functions.dart';
import 'package:onyva_mobile/core/widgets/color_sets.dart';
import 'package:onyva_mobile/models/e-pedigree.dart';
import 'package:onyva_mobile/models/enums/maintenance.dart';
import 'package:onyva_mobile/viewmodel/e-pedigree_viewmodel.dart';
import 'package:onyva_mobile/viewmodel/impl/e-pedigree_viewmodel_impl.dart';

Widget MaintenanceItem(BuildContext context, EPedigreeModel pedigree) {
  final EPedigreeViewModel _viewModel = new EPedigreeViewModelImpl();

  final pannerPath = pedigree.maintenanceType == MaintenanceTypesEnum.EM
      ? "lib/assets/red_spanner.svg"
      : "lib/assets/blue_spanner.svg";

  return Container(
      width: double.infinity,
      child: Container(
          alignment: Alignment.center,
          decoration:
              BoxDecoration(border: Border.all(color: ColorSets.lightGray)),
          child: InkWell(
            onTap: () =>
                {_viewModel.goToEPedigreeMaintenance(context, pedigree)},
            child: Column(
              children: [
                SizedBox(height: 8),
                Row(
                  children: [
                    SizedBox(height: 10, width: 20),
                    SvgPicture.asset(
                      pannerPath,
                      height: 20,
                    ),
                    SizedBox(height: 2, width: 24),
                    Text(getNameOfManutentionType2(pedigree.maintenanceType),
                        style: TextStyle(
                          color: ColorSets.lightGray,
                          fontSize: 20,
                        )),
                  ],
                ),
                SizedBox(height: 10),
                Text(pedigree.repairShop.name,
                    style: TextStyle(
                      color: ColorSets.lightGray,
                      fontSize: 24,
                    )),
                SizedBox(height: 10),
                Text(
                    DateFormat('dd/MM/yyyy')
                        .format(DateTime.parse(pedigree.date))
                        .toString(),
                    style: TextStyle(
                      color: ColorSets.lightGray,
                      fontSize: 24,
                    )),
                SizedBox(height: 25),
                Text("Clique aqui para mais informações",
                    style: TextStyle(
                      color: ColorSets.lightGray,
                      fontSize: 16,
                    )),
                SizedBox(height: 8),
              ],
            ),
          )));
}
