import 'package:flutter/material.dart';
import 'package:flutter_svg/svg.dart';
import 'package:onyva_mobile/core/widgets/stars.dart';
import 'package:onyva_mobile/models/repair_shop.dart';

class RepairShopCard extends StatefulWidget {
  final RepairShop repairShop;
  final Color imageBackgroundColor;
  final Color imageColor;
  final Color infosBackgroundColor;
  final Color infosTextColor;
  final Color starsColor;

  RepairShopCard(
      {this.repairShop,
      this.imageBackgroundColor,
      this.imageColor,
      this.infosBackgroundColor,
      this.infosTextColor,
      this.starsColor});

  @override
  _RepairShopCardState createState() => _RepairShopCardState();
}

class _RepairShopCardState extends State<RepairShopCard> {
  @override
  Widget build(BuildContext context) {
    return Container(
      height: 120,
      width: double.infinity,
      child: Row(
        crossAxisAlignment: CrossAxisAlignment.stretch,
        children: [
          Container(
            color: widget.imageBackgroundColor,
            padding: EdgeInsets.all(10),
            width: 100,
            child: SvgPicture.asset(
              // https://www.iconfinder.com/icons/111002/camera_icon
              'lib/assets/camera-icon.svg',
              color: widget.imageColor,
            ),
          ),
          Expanded(
            child: Container(
              padding: EdgeInsets.all(5),
              color: widget.infosBackgroundColor,
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Text(
                    widget.repairShop.name == null
                        ? "None"
                        : widget.repairShop.name,
                    textAlign: TextAlign.left,
                    style: TextStyle(
                      fontSize: 18,
                      color: widget.infosTextColor,
                    ),
                  ),
                  SizedBox(
                    height: 2.5,
                  ),
                  Text(
                    widget.repairShop.address == null
                        ? "None"
                        : widget.repairShop.address,
                    textAlign: TextAlign.left,
                    style: TextStyle(
                      fontSize: 15,
                      color: widget.infosTextColor,
                    ),
                  ),
                  Text(
                    (widget.repairShop.distance == null
                            ? "None"
                            : widget.repairShop.distance.toString()) +
                        " km de distância",
                    textAlign: TextAlign.left,
                    style: TextStyle(
                      fontSize: 15,
                      color: widget.infosTextColor,
                    ),
                  ),
                  Container(
                    height: 30,
                    child: Text(
                      (widget.repairShop.specialities == null
                          ? "Nenhuma"
                          : widget.repairShop.specialities.join(', ')),
                      textAlign: TextAlign.left,
                      maxLines: 2,
                      overflow: TextOverflow.ellipsis,
                      style: TextStyle(
                        fontSize: 13,
                        color: widget.infosTextColor,
                      ),
                    ),
                  ),
                  Stars(
                    starsCount: 5,
                    color: widget.starsColor,
                  ),
                ],
              ),
            ),
          ),
        ],
      ),
    );
  }
}
