import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:onyva_mobile/core/widgets/color_sets.dart';

class ThemeFormField extends StatelessWidget {
  final String title;
  final int maxLength;
  final List<TextInputFormatter> formatters;
  final TextEditingController controller;
  final Widget counter;
  final TextInputType keyBoardType;
  final FormFieldValidator<String> validator;
  final String initialValue;
  final FocusNode focusNode;
  final Widget suffixIcon;
  final bool enabled;
  bool readOnly;
  bool obscureText;
  int maxLines;

  ThemeFormField(
    this.title, {
    this.maxLength,
    this.formatters,
    this.controller,
    this.counter,
    this.keyBoardType,
    this.validator,
    this.initialValue,
    this.focusNode,
    this.suffixIcon,
    this.enabled,
    this.readOnly = false,
    this.obscureText = false,
    this.maxLines = 1,
  });

  @override
  Widget build(BuildContext context) {
    return Theme(
      data: ThemeData(
        primaryColor: ColorSets.lightGray,
        errorColor: Colors.orange,
      ),
      child: TextFormField(
        maxLength: maxLength,
        inputFormatters: formatters,
        controller: controller,
        decoration: InputDecoration(
            filled: true,
            fillColor: Colors.white,
            contentPadding: const EdgeInsets.only(
              left: 14.0,
              bottom: 8.0,
              top: 8.0,
            ),
            focusedBorder: OutlineInputBorder(
              borderSide: BorderSide(color: Colors.white),
              borderRadius: BorderRadius.circular(25.7),
            ),
            enabledBorder: UnderlineInputBorder(
              borderSide: BorderSide(color: Colors.white),
              borderRadius: BorderRadius.circular(25.7),
            ),
            labelText: title,
            suffixIcon: suffixIcon,
            errorStyle: TextStyle(
              color: Colors.orange,
              decorationColor: Colors.orange,
            )),
        keyboardType: keyBoardType,
        validator: validator,
        initialValue: initialValue,
        enabled: enabled,
        focusNode: focusNode,
        readOnly: readOnly,
        obscureText: obscureText,
        maxLines: maxLines,
      ),
    );
  }
}
