import 'dart:io';

import 'package:camera/camera.dart';
import 'package:flutter/material.dart';
import 'package:flutter_localizations/flutter_localizations.dart';
import 'package:onyva_mobile/app_config.dart';
import 'package:onyva_mobile/view/loading_page.dart';
import 'package:onyva_mobile/app_routes.dart';
import 'package:onyva_mobile/view/main_page.dart';
import 'package:onyva_mobile/view/maintenance_status_page.dart';
import 'package:onyva_mobile/view/repair_shop_search_page.dart';
import 'package:onyva_mobile/view/scan_duty/scan_duty_page.dart';
import 'package:onyva_mobile/view/scheduled_maintenance_page.dart';
import 'package:onyva_mobile/view/sign_up_page.dart';
import 'package:onyva_mobile/view/terms_and_service_page.dart';
import 'package:onyva_mobile/view/login_page.dart';
import 'package:provider/provider.dart';
import 'package:onyva_mobile/view/vehicle_km_update_page.dart';

import 'state_managers/app_store.dart';

void main() {
  API_URL = Platform.isAndroid
      ? 'http://10.0.2.2:3000/api'
      : 'http://localhost:3000/api';

  runApp(MyApp());
}

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  AppStore appStore = new AppStore();
  var firstCamera;

  @override
  void initState() {
    availableCameras().then((cameras) {
      firstCamera =
          cameras != null && cameras.length > 0 ? cameras.first : null;
    });
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return MultiProvider(
      providers: [
        Provider<AppStore>.value(value: appStore),
      ],
      child: MaterialApp(
        title: "Onyva",
        initialRoute: AppRoutes.LOADING_PAGE,
        routes: {
          AppRoutes.LOADING_PAGE: (context) => LoadingPage(),
          AppRoutes.MAIN_PAGE: (context) => MainPage(),
          AppRoutes.SIGN_UP_PAGE: (context) => SignUpPage(),
          AppRoutes.TERMS_PAGE: (context) => TermsAndServicePage(),
          AppRoutes.LOGIN_PAGE: (context) => LoginPage(),
          AppRoutes.VEHICLE_KM_UPDATE_PAGE: (context) => VehicleKMUpdatePage(),
          AppRoutes.SCHEDULED_MAINTENANCE_PAGE: (context) =>
              ScheduledMaintenancePage(),
          AppRoutes.REPAIR_SHOP_SEARCH: (context) => RepairShopSearchPage(),
          AppRoutes.VEHICLE_REGISTER_PAGE: (context) =>
              ScanDutyPage(camera: firstCamera),
          AppRoutes.MAINTENANCE_STATUS_PAGE: (context) =>
              new MaintenanceStatusPage(),
        },
        localizationsDelegates: [
          GlobalMaterialLocalizations.delegate,
        ],
        supportedLocales: [
          const Locale('pt', 'BR'),
        ],
      ),
    );
  }
}
