import 'package:intl/intl.dart';
import 'package:onyva_mobile/models/enums/scheduled_maintenance_status.dart';
import 'package:onyva_mobile/models/repair_shop.dart';
import 'package:onyva_mobile/models/scheduled_maintenance.dart';

class MaintenanceScheduling {
  String maintenanceType;
  RepairShop repairShop;
  String owner;
  ScheduledMaintenance scheduledMaintenance;
  String vehicle;
  String maintenanceDescription;
  DateTime date;
  DateTime createdAt;
  MaintenanceSchedulingStatus status;

  MaintenanceScheduling({
    this.maintenanceType,
    this.repairShop,
    this.owner,
    this.scheduledMaintenance,
    this.vehicle,
    this.maintenanceDescription,
    this.date,
    this.createdAt,
    this.status,
  });

  MaintenanceScheduling.fromJson(Map<String, dynamic> json) {
    maintenanceType = json['maintenanceType'];
    repairShop = RepairShop.fromJson(json['repairShop']);
    owner = (json['owner'] is Map) ? json['owner']['id'] : json['owner'];
    scheduledMaintenance = json['scheduledMaintenance'] != null
        ? ScheduledMaintenance.fromJson(json['scheduledMaintenance'])
        : null;
    vehicle = json['vehicle'] is Map ? json['vehicle']['id'] : json['vehicle'];
    maintenanceDescription = json['maintenanceDescription'];
    date = json['date'] != null ? DateTime.parse(json['date']) : null;
    createdAt =
        json['createdAt'] != null ? DateTime.parse(json['createdAt']) : null;
    status = decodeMaintenanceSchedulingStatusFrom(json['status']);
  }

  Map<String, dynamic> toJson() {
    final DateFormat dateFormatter = DateFormat('yyyy-MM-ddTHH:mm:ss');

    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['maintenanceType'] = this.maintenanceType;
    data['repairShop'] = this.repairShop.id;
    data['owner'] = this.owner;
    data['scheduledMaintenance'] =
        this.scheduledMaintenance != null ? this.scheduledMaintenance.id : null;
    data['vehicle'] = this.vehicle;
    data['maintenanceDescription'] = this.maintenanceDescription;
    data['date'] = this.date != null ? dateFormatter.format(this.date) : null;

    data['createdAt'] =
        this.createdAt != null ? dateFormatter.format(this.createdAt) : null;

    return data;
  }
}
