import 'dart:convert';

import 'package:onyva_mobile/app_config.dart';
import 'package:onyva_mobile/core/exceptions/remote_repository_exception.dart';
import 'package:onyva_mobile/core/models/repositories/remote/remote_repository_exception_type.dart';
import 'package:onyva_mobile/core/repositories/remote/implementation/remote_repository_adapter_impl.dart';
import 'package:onyva_mobile/core/repositories/remote/remote_repository_adapter.dart';
import 'package:onyva_mobile/core/utils/string_utils.dart';
import 'package:onyva_mobile/repositories/authentication_repository.dart';

class AuthenticationRepositoryImpl implements AuthenticationRepository {
  final RemoteRepositoryAdapter _remoteRepositoryAdapter =
      RemoteRepositoryAdapterImpl();

  @override
  Future<Map<String, dynamic>> authenticate(
    String email,
    String password,
  ) async {
    Map<String, String> params = {
      'email': email,
      'password': password,
    };

    final response = await _remoteRepositoryAdapter.get<String>(
      '$API_URL/owners',
      queryParameters: params,
    );

    if (response.statusCode != 200) {
      RemoteRepositoryException exc = new RemoteRepositoryException(
          remoteRepositoryExceptionType:
              RemoteRepositoryExceptionType.BAD_REQUEST,
          originalMessage: "Usuário e/ou senha inválidos.");
      return Future.error(exc);
    }

    return StringUtils.isBlank(response.responseBody)
        ? null
        : json.decode(response.responseBody);
  }

  Future<Map<String, dynamic>> getUserDataFromFacebookByToken(
    String token,
  ) async {
    final response =
        await _remoteRepositoryAdapter.get<String>("$FACEBOOK_API_URL$token");

    return json.decode(response.responseBody);
  }
}
