import 'dart:convert';

import 'package:onyva_mobile/app_config.dart';
import 'package:onyva_mobile/core/repositories/remote/implementation/remote_repository_adapter_impl.dart';
import 'package:onyva_mobile/core/repositories/remote/remote_repository_adapter.dart';
import 'package:onyva_mobile/core/utils/string_utils.dart';
import 'package:onyva_mobile/models/maintenance_scheduling.dart';
import 'package:onyva_mobile/repositories/maintenance_repository.dart';

class MaintenanceRepositoryImpl implements MaintenanceRepository {
  RemoteRepositoryAdapter _remoteRepositoryAdapter =
      new RemoteRepositoryAdapterImpl();

  @override
  Future<List<dynamic>> getScheduledMaintenancesByBrandModel(
      String brand, String model) async {
    Map<String, dynamic> queryParams = {
      "brandModel":
          brand.toString().toUpperCase() + model.toString().toUpperCase(),
    };

    final response = await _remoteRepositoryAdapter.get<String>(
      '$API_URL/fipe-vehicle',
      queryParameters: queryParams,
    );

    if (!StringUtils.isBlank(response.responseBody)) {
      var jsonResponse = json.decode(response.responseBody);
      if (jsonResponse != null) {
        return jsonResponse['scheduledMaintenances'];
      }
    }
    return null;
  }

  @override
  Future<MaintenanceScheduling> scheduleMaintenance(
    MaintenanceScheduling maintenanceScheduling,
  ) async {
    final response = await _remoteRepositoryAdapter.post<String>(
      '$API_URL/maintenance-schedules',
      maintenanceScheduling.toJson(),
    );

    return MaintenanceScheduling.fromJson(json.decode(response.responseBody));
  }

  @override
  Future<MaintenanceScheduling> getScheduledMaintenanceRequestPendingApproval(
    String ownerId,
  ) async {
    final queryParameters = {
      'maintenanceType': 'SM',
      'status': 'SE',
    };

    final response = await _remoteRepositoryAdapter.get<String>(
      '$API_URL/owners/$ownerId/maintenance-schedules',
      queryParameters: queryParameters,
    );

    if (response.statusCode == 204) {
      return null;
    }

    final jsonResponse = json.decode(response.responseBody);

    return MaintenanceScheduling.fromJson((jsonResponse as List).first);
  }
}
