import 'dart:convert';
import 'dart:io' as Io;
import 'package:flutter/cupertino.dart';
import 'package:onyva_mobile/app_config.dart';
import 'package:onyva_mobile/core/repositories/remote/implementation/remote_repository_adapter_impl.dart';
import 'package:onyva_mobile/core/repositories/remote/remote_repository_adapter.dart';
import 'package:onyva_mobile/models/owner.dart';
import 'package:onyva_mobile/models/vehicle.dart';
import 'package:onyva_mobile/repositories/ocr_repository.dart';
import 'package:onyva_mobile/state_managers/app_store.dart';
import 'package:provider/provider.dart';

class OcrRepositoryImpl extends OcrRepository {
  final RemoteRepositoryAdapter _remoteRepositoryAdapter =
      RemoteRepositoryAdapterImpl();

  Future<Vehicle> sendVehicleImage(String imagePath) async {
    print("PAssou aqui");
    try {
      String base64Image = base64Encode(Io.File(imagePath).readAsBytesSync());

      final response = await _remoteRepositoryAdapter.post<String>(
          '$API_URL/ocr', jsonEncode(<String, String>{'image': base64Image}));
      dynamic json = jsonDecode(response.responseBody);
      return Vehicle.fromJson(json);
    } catch (e) {
      print('Error on OCR ' + e.toString());
    }
    return null;
  }

  @override
  Future<Owner> saveVehicle(Vehicle body, BuildContext context) async {
    try {
      AppStore appStore = Provider.of<AppStore>(context, listen: false);
      final id = appStore.loggedOwner.id;
      Map<String, dynamic> params = {"id": id, "vehicle": body};

      final response =
          await _remoteRepositoryAdapter.patch('$API_URL/owners', params);
      Map<String, dynamic> json = response.responseBody;
      return Owner.fromJson(json);
    } catch (e) {
      print('Error on Save vehicle ' + e.toString());
    }
    return null;
  }
}
