import 'dart:convert';

import 'package:onyva_mobile/app_config.dart';
import 'package:onyva_mobile/core/repositories/remote/implementation/remote_repository_adapter_impl.dart';
import 'package:onyva_mobile/core/repositories/remote/remote_repository_adapter.dart';
import 'package:onyva_mobile/core/utils/string_utils.dart';
import 'package:onyva_mobile/models/repair_shop_calendar.dart';
import 'package:onyva_mobile/repositories/repair_shop_repository.dart';

class RepairShopRepositoryImpl implements RepairShopRepository {
  final RemoteRepositoryAdapter _remoteRepositoryAdapter =
      RemoteRepositoryAdapterImpl();

  @override
  Future<List<dynamic>> getRepairShops(List<String> services) async {
    Map<String, dynamic> queryParameters = {
      "services": services,
    };

    final response = await _remoteRepositoryAdapter.get<String>(
      '$API_URL/repair-shop/services',
      queryParameters: queryParameters,
    );

    return StringUtils.isBlank(response.responseBody)
        ? null
        : json.decode(response.responseBody);
  }

  @override
  Future<List<Map<String, dynamic>>> getRepairShopCalendar(
    int repairShopId,
  ) async {
    Map<String, dynamic> queryParameters = {
      "repairShopId": repairShopId,
    };

    final response = await _remoteRepositoryAdapter.get<List<dynamic>>(
      '$API_URL/calendar',
      queryParameters: queryParameters,
    );

    return response.responseBody != null && response.responseBody.isNotEmpty
        ? response.responseBody.map((e) => e as Map<String, dynamic>).toList()
        : [];
  }
}
