import 'package:flutter/material.dart';
import 'package:flutter/scheduler.dart';
import 'package:flutter/services.dart';
import 'package:flutter/widgets.dart';
import 'package:flutter_mobx/flutter_mobx.dart';
import 'package:onyva_mobile/app_routes.dart';
import 'package:onyva_mobile/core/utils/functions.dart';
import 'package:onyva_mobile/core/widgets/theme_button.dart';
import 'package:onyva_mobile/core/widgets/app_bars.dart';
import 'package:onyva_mobile/core/widgets/color_sets.dart';
import 'package:onyva_mobile/core/widgets/theme_form_field.dart';
import 'package:onyva_mobile/models/enums/login_type.dart';
import 'package:onyva_mobile/validators/login_page_validator.dart';
import 'package:onyva_mobile/viewmodel/impl/login_viewmodel_impl.dart';
import 'package:onyva_mobile/viewmodel/login_viewmodel.dart';

class LoginPage extends StatefulWidget {
  @override
  _LoginPageState createState() => _LoginPageState();
}

class _LoginPageState extends State<LoginPage> {
  static final GlobalKey<FormState> formKey = GlobalKey<FormState>();

  final LoginViewModel _loginViewModel = LoginViewModelImpl();

  @override
  void initState() {
    SchedulerBinding.instance.addPostFrameCallback((_) {
      _loginViewModel.goToHomePageIfHasBeenAuthenticated(context);
    });

    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    final size = MediaQuery.of(context).size;

    return Scaffold(
      body: Container(
        color: ColorSets.gray,
        width: double.infinity,
        height: double.infinity,
        alignment: Alignment.center,
        child: SingleChildScrollView(
          child: Column(
            children: [
              Container(
                child: Text(
                  'Onyva',
                  style: TextStyle(
                    fontSize: 48,
                    color: ColorSets.lightGray,
                  ),
                ),
              ),
              Container(
                child: Form(
                  key: formKey,
                  child: Container(
                    width: size.width - 50,
                    margin: EdgeInsets.only(top: 50),
                    child: Column(
                      children: [
                        Container(
                          width: size.width - 50,
                          child: ThemeFormField(
                            'E-mail',
                            keyBoardType: TextInputType.emailAddress,
                            validator: LoginPageValidator.validateEmail,
                            controller: _loginViewModel.emailCtrl,
                          ),
                        ),
                        SizedBox(height: 15),
                        Observer(builder: (BuildContext context) {
                          return ThemeFormField(
                            'Senha',
                            suffixIcon: IconButton(
                              icon: Icon(
                                _loginViewModel.showPassword
                                    ? Icons.visibility_off
                                    : Icons.visibility,
                                color: ColorSets.darkGray,
                              ),
                              onPressed: () {
                                _loginViewModel.toggleObscureText();
                              },
                            ),
                            controller: _loginViewModel.passwordCtrl,
                            obscureText: !_loginViewModel.showPassword,
                            validator: LoginPageValidator.validatePassword,
                          );
                        }),
                        SizedBox(height: 25),
                        InkWell(
                          child: Column(
                            children: [
                              Container(
                                alignment: Alignment.centerRight,
                                child: Text(
                                  'Não consegue acessar?',
                                  style: TextStyle(
                                    decoration: TextDecoration.underline,
                                    color: Colors.white,
                                  ),
                                ),
                              )
                            ],
                          ),
                        ),
                        SizedBox(height: 35),
                        Observer(builder: (BuildContext context) {
                          return this._loginViewModel.isLoading
                              ? Center(
                                  child: CircularProgressIndicator(
                                    valueColor: AlwaysStoppedAnimation<Color>(
                                      ColorSets.blue,
                                    ),
                                  ),
                                )
                              : ThemeButton(
                                  text: 'ENTRAR',
                                  action: () {
                                    if (!formKey.currentState.validate()) {
                                      return;
                                    }

                                    _loginViewModel.login(
                                      context,
                                      LoginType.REGISTRATION,
                                    );
                                  });
                        }),
                        SizedBox(height: 35),
                        Column(
                          children: [
                            Container(
                              child: Text(
                                'Ou entre usando sua conta em:',
                                style: TextStyle(color: Colors.white),
                              ),
                            ),
                            SizedBox(height: 10),
                            InkWell(
                              child: Image.asset(
                                'lib/assets/facebook.png',
                                width: 50,
                                height: 50,
                              ),
                              onTap: () => _loginViewModel.login(
                                context,
                                LoginType.FACEBOOK,
                              ),
                            )
                          ],
                        ),
                        SizedBox(height: 35),
                        Column(
                          children: [
                            Container(
                              child: Row(
                                mainAxisAlignment: MainAxisAlignment.center,
                                children: [
                                  Text(
                                    'Novo por aqui? ',
                                    style: TextStyle(
                                      color: Colors.white,
                                      fontSize: 16,
                                    ),
                                  ),
                                  InkWell(
                                    child: Text(
                                      'Cadastre-se agora!',
                                      style: TextStyle(
                                        color: Colors.white,
                                        fontWeight: FontWeight.bold,
                                        fontSize: 16,
                                        decoration: TextDecoration.underline,
                                      ),
                                    ),
                                    onTap: () => pushNamed(
                                      context,
                                      AppRoutes.SIGN_UP_PAGE,
                                    ),
                                  ),
                                ],
                              ),
                            ),
                          ],
                        ),
                      ],
                    ),
                  ),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
