import 'package:flutter/material.dart';
import 'package:flutter_mobx/flutter_mobx.dart';
import 'package:onyva_mobile/business/authentication_business.dart';
import 'package:onyva_mobile/business/implementation/authentication_business_impl.dart';
import 'package:onyva_mobile/app_routes.dart';
import 'package:onyva_mobile/core/utils/functions.dart';
import 'package:onyva_mobile/core/widgets/app_bars.dart';
import 'package:onyva_mobile/core/widgets/color_sets.dart';
import 'package:onyva_mobile/core/widgets/theme_button.dart';
import 'package:onyva_mobile/models/requested_maintenance.dart';
import 'package:onyva_mobile/models/vehicle.dart';
import 'package:onyva_mobile/state_managers/app_store.dart';
import 'package:onyva_mobile/viewmodel/e-pedigree_viewmodel.dart';
import 'package:onyva_mobile/viewmodel/impl/e-pedigree_viewmodel_impl.dart';
import 'package:onyva_mobile/viewmodel/impl/main_viewmodel_impl.dart';
import 'package:onyva_mobile/viewmodel/main_viewmodel.dart';
import 'package:provider/provider.dart';

class MainPage extends StatefulWidget {
  @override
  MainPageState createState() => MainPageState();
}

class MainPageState extends State<MainPage> {
  final AuthenticationBusiness authenticationBusiness =
      AuthenticationBusinessImpl();
  final MainViewModel _viewModel = new MainViewModelImpl();
  final EPedigreeViewModel _ePedigreeviewModel = new EPedigreeViewModelImpl();

  @override
  Widget build(BuildContext context) {
    AppStore appStore = Provider.of<AppStore>(context);
    final size = MediaQuery.of(context).size;
    final appBar1 = AppBarCustom(context, "Onyva");
    return Scaffold(
      resizeToAvoidBottomPadding: true,
      appBar: appBar1,
      drawer: Drawer(
        child: Container(
          padding: EdgeInsets.symmetric(
            horizontal: 10,
          ),
          color: ColorSets.darkGray,
          child: ListView(
            shrinkWrap: true,
            children: [
              SizedBox(
                height: 20,
              ),
              Text(
                'Onyva',
                textAlign: TextAlign.center,
                style: TextStyle(
                  fontSize: 38,
                  color: ColorSets.lightGray,
                ),
              ),
              SizedBox(
                height: 20,
              ),
              FlatButton(
                onPressed: () {
                  _viewModel.goToVehicleRegisterPage(context);
                },
                child: Container(
                  width: double.infinity,
                  padding: EdgeInsets.symmetric(vertical: 10),
                  color: ColorSets.lightGray,
                  child: Text(
                    "Cadastrar um veículo",
                    style: TextStyle(
                      fontSize: 16,
                    ),
                    textAlign: TextAlign.center,
                  ),
                ),
              ),
              SizedBox(
                height: 20,
              ),
              Text(
                'Seus Veículos:',
                textAlign: TextAlign.center,
                style: TextStyle(
                  fontSize: 18,
                  color: ColorSets.lightGray,
                ),
              ),
              SizedBox(
                height: 10,
              ),
              Observer(
                builder: (context) {
                  return Column(
                    children: appStore.loggedOwner.vehicles == null
                        ? [
                            Text(
                              "Nenhum veículo encontrado",
                              style: TextStyle(
                                color: ColorSets.lightGray,
                                fontSize: 14,
                              ),
                            ),
                          ]
                        : (appStore.loggedOwner.vehicles.map((Vehicle vehicle) {
                            return FlatButton(
                              onPressed: () {
                                _viewModel.selectVehicle(context, vehicle);
                              },
                              child: Container(
                                color: appStore.currentVehicle != null &&
                                        appStore.currentVehicle.id == vehicle.id
                                    ? ColorSets.blue
                                    : ColorSets.lightGray,
                                width: double.infinity,
                                padding: EdgeInsets.symmetric(vertical: 10),
                                child: Text(
                                  vehicle.licensePlate +
                                      ' (' +
                                      vehicle.modelYear.toString() +
                                      ')',
                                  maxLines: 2,
                                  textAlign: TextAlign.center,
                                  style: TextStyle(
                                    fontSize: 16,
                                  ),
                                ),
                              ),
                            );
                          }).toList()),
                  );
                },
              ),
            ],
          ),
        ),
      ),
      body: Container(
        color: ColorSets.gray,
        alignment: Alignment.center,
        width: double.infinity,
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: [
            Text(
              "Bem-vindo " + appStore.loggedOwner.name,
              style: TextStyle(
                color: ColorSets.lightGray,
                fontSize: 36,
              ),
              textAlign: TextAlign.center,
            ),
            SizedBox(
              height: 20,
            ),
            Observer(
              builder: (context) {
                return appStore.currentVehicle != null
                    ? Column(
                        children: [
                          Text(
                            'Placa do veículo: ' +
                                appStore.currentVehicle.licensePlate,
                            style: TextStyle(
                              color: ColorSets.lightGray,
                              fontSize: 24,
                            ),
                            textAlign: TextAlign.center,
                          ),
                          SizedBox(
                            height: 20,
                          ),
                          ThemeButton(
                            text: 'Manutencao Programada',
                            action: () => _viewModel.goToScheduledMaintenance(
                                context, ManutentionType.SCHEDULED),
                          ),
                          SizedBox(
                            height: 10,
                          ),
                          ThemeButton(
                            text: 'Manutenções Não Programadas',
                            action: () => _viewModel.goToScheduledMaintenance(
                                context, ManutentionType.ALL),
                          ),
                          SizedBox(
                            height: 10,
                          ),
                          ThemeButton(
                            text: 'Atualizar Quilometragem',
                            action: () =>
                                _viewModel.goToVehicleKmUpdate(context),
                          ),
                          SizedBox(
                            height: 10,
                          ),
                          ThemeButton(
                              text: 'E-Pedigree',
                              action: () async {
                                final response = await _ePedigreeviewModel
                                    .ePedigree(appStore.currentVehicle.id);
                                _viewModel.goToEPedigree(context, response);
                              }),
                        ],
                      )
                    : Text(
                        'Nenhum veículo selecionado',
                        style: TextStyle(
                          color: ColorSets.lightGray,
                          fontSize: 16,
                        ),
                        textAlign: TextAlign.center,
                      );
              },
            ),
          ],
        ),
      ),
      floatingActionButton: Container(
        alignment: Alignment.bottomLeft,
        margin: EdgeInsets.only(left: 30),
        child: FloatingActionButton(
          onPressed: () {
            authenticationBusiness.logouUser().then(
              (value) {
                pushNamedAndRemoveUntil(context, AppRoutes.LOGIN_PAGE);
              },
            );
          },
          child: Icon(
            Icons.arrow_back,
            color: ColorSets.blue,
          ),
          backgroundColor: ColorSets.darkGray,
        ),
      ),
    );
  }
}
