import 'package:flutter/material.dart';
import 'package:intl/intl.dart';
import 'package:onyva_mobile/core/widgets/app_bars.dart';
import 'package:onyva_mobile/core/widgets/color_sets.dart';
import 'package:onyva_mobile/models/enums/scheduled_maintenance_status.dart';
import 'package:onyva_mobile/models/maintenance_scheduling.dart';
import 'package:onyva_mobile/models/requested_maintenance.dart';

class MaintenanceStatusPage extends StatefulWidget {
  @override
  MaintenanceStatusPageState createState() => MaintenanceStatusPageState();
}

class MaintenanceStatusPageState extends State<MaintenanceStatusPage> {
  MaintenanceScheduling rm;

  @override
  Widget build(BuildContext context) {
    //AppStore appStore = Provider.of<AppStore>(context);

    if (rm == null) print(ModalRoute.of(context).settings.arguments);
    rm = ModalRoute.of(context).settings.arguments as MaintenanceScheduling;

    final appBar1 = AppBarCustom(context, "Onyva");

    return Scaffold(
      resizeToAvoidBottomPadding: true,
      appBar: appBar1,
      body: Container(
        color: ColorSets.gray,
        width: double.infinity,
        alignment: Alignment.center,
        padding: EdgeInsets.symmetric(
          horizontal: 20,
        ),
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            Center(
              child: Icon(
                Icons.check_circle_outline,
                size: 70,
                color: Colors.green,
              ),
            ),
            SizedBox(
              height: 20,
            ),
            RichText(
              text: TextSpan(
                  style: TextStyle(
                    fontSize: 18,
                  ),
                  children: [
                    TextSpan(
                      text: 'Seu agendamento foi solicitado com sucesso!\n',
                      style: TextStyle(
                        color: ColorSets.lightGray,
                      ),
                    ),
                    TextSpan(
                      text: 'Dentro de ',
                      style: TextStyle(
                        color: ColorSets.lightGray,
                      ),
                    ),
                    TextSpan(
                      text: '24 horas',
                      style: TextStyle(
                        color: Colors.white,
                      ),
                    ),
                    TextSpan(
                      text:
                          ' a oficina dará um retorno sobre a sua solicitação.',
                      style: TextStyle(
                        color: ColorSets.lightGray,
                      ),
                    )
                  ]),
            ),
            SizedBox(
              height: 30,
            ),
            Text(
              'Detalhes do agendamento:',
              style: TextStyle(
                color: Colors.white,
                fontSize: 20,
              ),
            ),
            SizedBox(
              height: 10,
            ),
            Padding(
              padding: EdgeInsets.symmetric(horizontal: 20),
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  RichText(
                    text: TextSpan(
                      style: TextStyle(
                        fontSize: 18,
                      ),
                      children: [
                        TextSpan(
                          text: "Oficina: ",
                          style: TextStyle(
                            color: Colors.white,
                          ),
                        ),
                        TextSpan(
                          text: (rm.repairShop == null
                                  ? "None"
                                  : rm.repairShop.name) +
                              "\n",
                          style: TextStyle(
                            color: ColorSets.lightGray,
                          ),
                        ),
                        TextSpan(
                          text: "Data da solicitação: ",
                          style: TextStyle(
                            color: Colors.white,
                          ),
                        ),
                        TextSpan(
                          text: new DateFormat("dd/MM/yyyy")
                                  .format(rm.createdAt) +
                              "\n",
                          style: TextStyle(
                            color: ColorSets.lightGray,
                          ),
                        ),
                        TextSpan(
                          text: "Horário da solicitação: ",
                          style: TextStyle(
                            color: Colors.white,
                          ),
                        ),
                        TextSpan(
                          text: new DateFormat.Hm().format(rm.createdAt) + "\n",
                          style: TextStyle(
                            color: ColorSets.lightGray,
                          ),
                        ),
                        TextSpan(
                          text: "Agendamento solicitado para: ",
                          style: TextStyle(
                            color: Colors.white,
                          ),
                        ),
                        TextSpan(
                          text: DateFormat("dd/MM/yyyy 'à\s' HH:mm")
                                  .format(rm.date) +
                              "\n",
                          style: TextStyle(
                            color: ColorSets.lightGray,
                          ),
                        ),
                        TextSpan(
                          text: "Endereço: ",
                          style: TextStyle(
                            color: Colors.white,
                          ),
                        ),
                        TextSpan(
                          text: (rm.repairShop == null
                                  ? "None"
                                  : rm.repairShop.address) +
                              "\n",
                          style: TextStyle(
                            color: ColorSets.lightGray,
                          ),
                        ),
                        TextSpan(
                          text: "Status: ",
                          style: TextStyle(
                            color: Colors.white,
                          ),
                        ),
                        TextSpan(
                          text: getMaintenanceSchedulingStatusText(rm.status),
                          style: TextStyle(
                            color: ColorSets.lightGray,
                          ),
                        ),
                        WidgetSpan(
                          child: Icon(
                            Icons.access_time,
                            color: Colors.lightGreen,
                          ),
                        )
                      ],
                    ),
                  ),
                ],
              ),
            ),
            SizedBox(
              height: 20,
            ),
          ],
        ),
      ),
    );
  }
}
