import 'package:flutter/material.dart';
import 'package:flutter_mobx/flutter_mobx.dart';
import 'package:onyva_mobile/core/widgets/app_bars.dart';
import 'package:onyva_mobile/core/widgets/color_sets.dart';
import 'package:onyva_mobile/core/widgets/repair_shop_card.dart';
import 'package:onyva_mobile/core/widgets/speciality_checkbox.dart';
import 'package:onyva_mobile/core/widgets/theme_button.dart';
import 'package:onyva_mobile/viewmodel/impl/repair_shop_search_viewmodel_impl.dart';
import 'package:onyva_mobile/viewmodel/repair_shop_search_viewmodel.dart';

class RepairShopSearchPage extends StatefulWidget {
  @override
  _RepairShopSearchPageState createState() => _RepairShopSearchPageState();
}

class _RepairShopSearchPageState extends State<RepairShopSearchPage> {
  RepairShopSearchViewModel _viewModel = new RepairShopSearchViewModelImpl();

  @override
  Widget build(BuildContext context) {
    //AppStore appStore = Provider.of<AppStore>(context);
    final args = ModalRoute.of(context).settings.arguments;
    _viewModel.processArgs(args);

    _viewModel.updateRepairShops(context);
    return Scaffold(
      resizeToAvoidBottomPadding: true,
      appBar: AppBarCustom(context, "Buscar Oficina"),
      body: Container(
        color: ColorSets.gray,
        width: double.infinity,
        height: double.infinity,
        child: ListView(
          scrollDirection: Axis.vertical,
          shrinkWrap: true,
          padding: EdgeInsets.symmetric(vertical: 20, horizontal: 16.0),
          children: [
            Observer(
              builder: (context) {
                if (_viewModel.showFilters) {
                  _viewModel.loadAllPossibleFilters(context);

                  return Column(
                    children: [
                      Text(
                        "Selecione os serviços que deseja:",
                        style: TextStyle(
                          color: ColorSets.lightGray,
                          fontSize: 20,
                        ),
                        textAlign: TextAlign.center,
                      ),
                      SizedBox(
                        height: 5,
                      ),
                      Container(
                        decoration: BoxDecoration(
                          border: Border.all(
                            color: ColorSets.darkGray,
                            width: 2,
                          ),
                        ),
                        height: 200,
                        child: Observer(builder: (context) {
                          return GridView.count(
                            crossAxisCount: 2,
                            padding: EdgeInsets.all(0),
                            shrinkWrap: true,
                            childAspectRatio: 5,
                            children: _viewModel.services
                                .asMap()
                                .entries
                                .map((entry) {
                              int index = entry.key;
                              Map<String, dynamic> speciality = entry.value;
                              return SpecialityCheckBox(
                                  specialityName: speciality['name'],
                                  value: speciality['selected'],
                                  onChanged: (v) {
                                    speciality['selected'] = v;
                                    _viewModel.updateServices(
                                        context, index, speciality);
                                  });
                            }).toList(),
                          );
                        }),
                      ),
                      SizedBox(
                        height: 10,
                      ),
                    ],
                  );
                } else {
                  return Container();
                }
              },
            ),
            Text(
              "Oficinas:",
              style: TextStyle(
                color: ColorSets.lightGray,
                fontSize: 20,
              ),
              textAlign: TextAlign.center,
            ),
            SizedBox(
              height: 10,
            ),
            Observer(
              builder: (context) {
                return Column(
                  children: _viewModel.isBusy == false
                      ? (_viewModel.resultRepairShops.length > 0
                          ? _viewModel.resultRepairShops.map((repairShop) {
                              return Column(
                                children: [
                                  GestureDetector(
                                    onTap: () {
                                      _viewModel.selectRepairShop(repairShop);
                                    },
                                    child: _viewModel.selectedRepairShop ==
                                            repairShop
                                        ? RepairShopCard(
                                            imageBackgroundColor:
                                                ColorSets.blue,
                                            imageColor: Colors.black,
                                            infosBackgroundColor:
                                                ColorSets.darkGray,
                                            infosTextColor: ColorSets.blue,
                                            repairShop: repairShop,
                                            starsColor: Colors.blue,
                                          )
                                        : RepairShopCard(
                                            imageBackgroundColor:
                                                Colors.white70,
                                            imageColor: Colors.black,
                                            infosBackgroundColor:
                                                ColorSets.darkGray,
                                            infosTextColor: ColorSets.lightGray,
                                            repairShop: repairShop,
                                            starsColor: Colors.white70,
                                          ),
                                  ),
                                  SizedBox(
                                    height: 20,
                                  ),
                                ],
                              );
                            }).toList()
                          : [
                              Text(
                                'Nenhuma oficina encontrada.',
                                style: TextStyle(
                                  fontSize: 20,
                                  color: ColorSets.lightGray,
                                ),
                                textAlign: TextAlign.center,
                              ),
                              SizedBox(
                                height: 20,
                              ),
                            ])
                      : [
                          CircularProgressIndicator(),
                          SizedBox(
                            height: 20,
                          ),
                        ],
                );
              },
            ),
            ThemeButton(
              text: 'Confirmar',
              action: () {
                _viewModel.confirm(context);
              },
            )
          ],
        ),
      ),
    );
  }
}
