import 'package:flutter/material.dart';
import 'package:flutter_mobx/flutter_mobx.dart';
import 'package:onyva_mobile/core/widgets/color_sets.dart';
import 'package:onyva_mobile/core/widgets/theme_button.dart';
import 'package:onyva_mobile/core/widgets/theme_form_field.dart';
import 'package:onyva_mobile/models/vehicle.dart';
import 'package:onyva_mobile/viewmodel/impl/ocr_viewmodel_impl.dart';
import 'package:onyva_mobile/viewmodel/ocr_viewmodel.dart';

class ConfirmCarInfo extends StatelessWidget {
  final Vehicle carInfo;

  const ConfirmCarInfo({Key key, this.carInfo}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    final GlobalKey<FormState> formKey = GlobalKey<FormState>();
    final OcrViewModel ocrViewModel = new OcrViewModelImpl();
    ocrViewModel.marcaCtrl.text = carInfo.fipeVehicle.brand;
    ocrViewModel.anoFabCtrl.text = carInfo.manufactureYear != null
        ? carInfo.manufactureYear.toString()
        : "";
    ocrViewModel.anoModCtrl.text =
        carInfo.modelYear != null ? carInfo.modelYear.toString() : "";
    ocrViewModel.licensePlateCtrl.text = carInfo.licensePlate;
    ocrViewModel.renavamCtrl.text = carInfo.renavamCode;
    ocrViewModel.modeloCtrl.text = carInfo.fipeVehicle.model;

    return Scaffold(
        backgroundColor: ColorSets.gray,
        appBar: AppBar(
          title: Text("Novo carro"),
          backgroundColor: ColorSets.darkBlue,
        ),
        body: new Container(
            // padding: const EdgeInsets.all(26.0),
            // width: cWidth,
            color: ColorSets.gray,
            width: double.infinity,
            height: double.infinity,
            alignment: Alignment.center,
            child: Container(
                child: Form(
              key: formKey,
              child: ListView(children: [
                SizedBox(
                  height: 40,
                ),
                ThemeFormField(
                  'Marca',
                  keyBoardType: TextInputType.text,
                  controller: ocrViewModel.marcaCtrl,
                ),
                SizedBox(
                  height: 20,
                ),
                ThemeFormField(
                  'Placa',
                  keyBoardType: TextInputType.text,
                  controller: ocrViewModel.licensePlateCtrl,
                ),
                SizedBox(
                  height: 20,
                ),
                ThemeFormField(
                  'Modelo',
                  keyBoardType: TextInputType.text,
                  controller: ocrViewModel.modeloCtrl,
                ),
                SizedBox(
                  height: 20,
                ),
                ThemeFormField(
                  'Ano modelo',
                  keyBoardType: TextInputType.number,
                  controller: ocrViewModel.anoModCtrl,
                ),
                SizedBox(
                  height: 20,
                ),
                ThemeFormField(
                  'Ano Fabricação',
                  keyBoardType: TextInputType.number,
                  controller: ocrViewModel.anoFabCtrl,
                ),
                SizedBox(
                  height: 20,
                ),
                ThemeFormField(
                  'Renavam',
                  keyBoardType: TextInputType.number,
                  controller: ocrViewModel.renavamCtrl,
                ),
                SizedBox(
                  height: 50,
                ),
                Observer(builder: (BuildContext context) {
                  return ocrViewModel.isbusy
                      ? Center(
                          child: CircularProgressIndicator(),
                        )
                      : Row(
                          mainAxisSize: MainAxisSize.min,
                          children: [
                            Flexible(
                              fit: FlexFit.tight,
                              child: ThemeButton(
                                  action: () async {
                                    final FormState form = formKey.currentState;
                                    form.save();
                                    if (!form.validate()) return;
                                    ocrViewModel.saveVehicle(context);
                                  },
                                  text: 'Cadastrar Carro'),
                            ),
                          ],
                        );
                }),
              ]),
            ))));
  }
}
