import 'package:camera/camera.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:onyva_mobile/core/widgets/color_sets.dart';
import 'package:path/path.dart';
import 'package:path_provider/path_provider.dart';
import 'package:onyva_mobile/view/scan_duty/confirm_duty_image.dart';
import 'package:toast/toast.dart';

class ScanDutyPage extends StatefulWidget {
  final CameraDescription camera;

  const ScanDutyPage({
    Key key,
    @required this.camera,
  }) : super(key: key);

  @override
  ScanDutyPageState createState() => ScanDutyPageState();
}

class ScanDutyPageState extends State<ScanDutyPage> {
  // Add two variables to the state class to store the CameraController and
  // the Future.
  CameraController _controller;
  Future<void> _initializeControllerFuture;

  @override
  void initState() {
    super.initState();
    _controller = CameraController(
      widget.camera,
      ResolutionPreset.ultraHigh,
    );
    _initializeControllerFuture = _controller.initialize();
  }

  @override
  void dispose() {
    _controller.dispose();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
          title: Text('Centralize o documento:'),
          backgroundColor: ColorSets.darkBlue),
      body: FutureBuilder<void>(
        future: _initializeControllerFuture,
        builder: (context, snapshot) {
          if (snapshot.connectionState == ConnectionState.done) {
            return CameraPreview(_controller);
          } else {
            return Center(child: CircularProgressIndicator());
          }
        },
      ),
      floatingActionButton: FloatingActionButton(
        child: Icon(
          Icons.camera_alt,
          color: Color.fromRGBO(500, 500, 500, 1),
        ),
        autofocus: true,
        backgroundColor: Color.fromRGBO(13, 13, 322, 1),
        onPressed: () async {
          try {
            await _initializeControllerFuture;

            final path = join(
              (await getTemporaryDirectory()).path,
              '${DateTime.now()}.png',
            );

            await _controller.takePicture(path);

            await Navigator.push(
              context,
              MaterialPageRoute(
                builder: (context) => ConfirmDutyImage(imagePath: path),
              ),
            );
          } catch (e) {
            Toast.show("Erro ao encontrar imagem", context,
                duration: Toast.LENGTH_SHORT,
                gravity: Toast.BOTTOM,
                backgroundColor: Color.fromRGBO(100, 0, 0, 1));
          }
        },
      ),
      floatingActionButtonLocation: FloatingActionButtonLocation.centerFloat,
    );
  }
}
