import 'package:auto_size_text/auto_size_text.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:flutter_mobx/flutter_mobx.dart';
import 'package:onyva_mobile/core/utils/functions.dart';
import 'package:onyva_mobile/core/utils/string_utils.dart';
import 'package:onyva_mobile/core/widgets/app_bars.dart';
import 'package:onyva_mobile/core/widgets/color_sets.dart';
import 'package:onyva_mobile/core/widgets/custom_radio.dart';
import 'package:onyva_mobile/core/widgets/custom_radio_group.dart';
import 'package:onyva_mobile/core/widgets/repair_shop_card.dart';
import 'package:onyva_mobile/core/widgets/theme_button.dart';
import 'package:onyva_mobile/core/widgets/theme_form_field.dart';
import 'package:onyva_mobile/models/requested_maintenance.dart';
import 'package:onyva_mobile/models/vehicle.dart';
import 'package:onyva_mobile/state_managers/app_store.dart';
import 'package:onyva_mobile/viewmodel/impl/scheduled_maintenance_viewmodel_impl.dart';
import 'package:onyva_mobile/viewmodel/scheduled_maintenance_viewmodel.dart';
import 'package:provider/provider.dart';

class ScheduledMaintenancePage extends StatefulWidget {
  @override
  _ScheduledMaintenancePageState createState() =>
      _ScheduledMaintenancePageState();
}

class _ScheduledMaintenancePageState extends State<ScheduledMaintenancePage> {
  final ScheduledMaintenanceViewModel _viewmodel =
      new ScheduledMaintenanceViewModelImpl();

  static final GlobalKey<FormState> formKey = GlobalKey<FormState>();

  @override
  void initState() {
    _viewmodel.loadRepairShopCalendar();

    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    AppStore appStore = Provider.of<AppStore>(context);

    final args = ModalRoute.of(context).settings.arguments;
    _viewmodel.processArgs(args, context);
    if (_viewmodel.manutentionType == ManutentionType.SCHEDULED)
      _viewmodel.loadManutentionOfCurrentVehicle(context);

    return WillPopScope(
      child: Scaffold(
        resizeToAvoidBottomPadding: true,
        appBar: AppBarCustom(
            context,
            "Agendamento de " +
                getNameOfManutentionType(_viewmodel.manutentionType)),
        body: Form(
          key: formKey,
          child: Container(
            color: ColorSets.gray,
            width: double.infinity,
            height: double.infinity,
            child: SingleChildScrollView(
              child: Column(
                children: [
                  Container(
                    margin: EdgeInsets.only(
                      bottom: 50,
                      top: 50,
                    ),
                    child: Observer(builder: (BuildContext context) {
                      Vehicle vehicle = appStore.currentVehicle;
                      return Text(
                        vehicle.licensePlate +
                            ' (' +
                            vehicle.modelYear.toString() +
                            ')',
                        style: TextStyle(
                          color: Colors.white,
                          fontSize: 36,
                          decoration: TextDecoration.underline,
                        ),
                        textAlign: TextAlign.center,
                      );
                    }),
                  ),
                  SizedBox(
                    height: 20,
                  ),
                  Container(
                    alignment: Alignment.centerLeft,
                    padding: EdgeInsets.only(left: 10),
                    child: Text(
                      "Oficina selecionada:",
                      style: TextStyle(
                        color: Colors.white,
                        fontSize: 18,
                        fontWeight: FontWeight.bold,
                      ),
                      textAlign: TextAlign.center,
                    ),
                  ),
                  SizedBox(
                    height: 20,
                  ),
                  Observer(builder: (context) {
                    return Container(
                      margin: EdgeInsets.only(
                        left: 30,
                        bottom: 30,
                      ),
                      child: _viewmodel.repairShop == null
                          ? Column(
                              children: [
                                AutoSizeText.rich(
                                  TextSpan(
                                    text: 'Nenhuma oficina selecionada. ',
                                    style: TextStyle(
                                      color: ColorSets.lightGray,
                                      fontSize: 18,
                                    ),
                                  ),
                                ),
                                AutoSizeText.rich(
                                  TextSpan(
                                    text: 'Escolha uma oficina!',
                                    recognizer: TapGestureRecognizer()
                                      ..onTap = () {
                                        _viewmodel.chooseRepairShop(context);
                                      },
                                    style: TextStyle(
                                        decoration: TextDecoration.underline,
                                        color: Colors.white,
                                        fontSize: 18,
                                        fontWeight: FontWeight.bold),
                                  ),
                                )
                              ],
                            )
                          : Column(
                              crossAxisAlignment: CrossAxisAlignment.end,
                              children: [
                                RepairShopCard(
                                  repairShop: _viewmodel.repairShop,
                                  imageBackgroundColor: Colors.transparent,
                                  imageColor: Colors.black,
                                  infosBackgroundColor: Colors.white,
                                  infosTextColor: ColorSets.darkGray,
                                  starsColor: ColorSets.darkGray,
                                ),
                                GestureDetector(
                                  onTap: () {
                                    _viewmodel.chooseRepairShop(context);
                                  },
                                  child: Text(
                                    "Trocar de oficina",
                                    style: TextStyle(
                                      color: Colors.white,
                                      fontSize: 18,
                                      decoration: TextDecoration.underline,
                                      fontWeight: FontWeight.bold,
                                    ),
                                  ),
                                ),
                              ],
                            ),
                    );
                  }),
                  SizedBox(
                    height: 20,
                  ),
                  Observer(
                    builder: (BuildContext context) {
                      return _viewmodel.repairShop != null
                          ? Column(
                              children: [
                                Container(
                                  alignment: Alignment.centerLeft,
                                  margin: EdgeInsets.only(left: 10),
                                  child: Text(
                                    "Data e Horário:",
                                    style: TextStyle(
                                      color: Colors.white,
                                      fontSize: 18,
                                      fontWeight: FontWeight.bold,
                                    ),
                                    textAlign: TextAlign.left,
                                  ),
                                ),
                                SizedBox(
                                  height: 10,
                                ),
                                Observer(
                                  builder: (context) => _viewmodel.isBusy
                                      ? Container()
                                      : _viewmodel.repairShopCalendar,
                                ),
                              ],
                            )
                          : Container();
                    },
                  ),
                  SizedBox(
                    height: 20,
                  ),
                  Container(
                    alignment: Alignment.centerLeft,
                    margin: EdgeInsets.only(left: 10),
                    child: Text(
                      "Serviços:",
                      style: TextStyle(
                        color: Colors.white,
                        fontSize: 18,
                        fontWeight: FontWeight.bold,
                      ),
                      textAlign: TextAlign.left,
                    ),
                  ),
                  SizedBox(
                    height: 10,
                  ),
                  Container(
                    padding: EdgeInsets.symmetric(horizontal: 15),
                    child: Observer(
                      builder: (context) {
                        return Text(
                            _viewmodel.servicesList.length == 0
                                ? 'Nenhum selecionado.'
                                : _viewmodel.servicesList.join(', '),
                            style: TextStyle(
                              color: ColorSets.lightGray,
                              fontSize: 18,
                            ),
                            textAlign: TextAlign.justify);
                      },
                    ),
                  ),
                  SizedBox(
                    height: 50,
                  ),
                  _viewmodel.showOptionalDetailsField
                      ? Container(
                          alignment: Alignment.centerLeft,
                          margin: EdgeInsets.symmetric(horizontal: 10),
                          child: Column(
                            crossAxisAlignment: CrossAxisAlignment.start,
                            children: [
                              SizedBox(
                                height: 10,
                              ),
                              Text(
                                "Título da manutenção:",
                                style: TextStyle(
                                  color: Colors.white,
                                  fontSize: 18,
                                  fontWeight: FontWeight.bold,
                                ),
                                textAlign: TextAlign.left,
                              ),
                              SizedBox(
                                height: 10,
                              ),
                              ThemeFormField(
                                "",
                                controller: _viewmodel.maintenanceTitleCtrl,
                                validator: (String value) {
                                  if (StringUtils.isBlank(value)) {
                                    return 'É necessário informar o título para a solicitação.';
                                  }

                                  return null;
                                },
                              ),
                            ],
                          ),
                        )
                      : Container(),
                  SizedBox(
                    height: 50,
                  ),
                  _viewmodel.showOptionalDetailsField
                      ? Observer(
                          builder: (BuildContext context) {
                            return Container(
                              alignment: Alignment.centerLeft,
                              margin: EdgeInsets.symmetric(horizontal: 10),
                              child: CustomRadioGroup(
                                [
                                  CustomRadio<ManutentionType>(
                                    'Urgente',
                                    _viewmodel.manutentionType,
                                    (ManutentionType value) {
                                      _viewmodel.setMaintenanceType(value);
                                    },
                                    ManutentionType.URGENT,
                                  ),
                                  CustomRadio<ManutentionType>(
                                    'Preventiva',
                                    _viewmodel.manutentionType,
                                    (ManutentionType value) {
                                      _viewmodel.setMaintenanceType(value);
                                    },
                                    ManutentionType.PREVENTIVE,
                                  ),
                                ],
                                'Tipo de manutenção',
                                MediaQuery.of(context).size.height,
                              ),
                            );
                          },
                        )
                      : Container(),
                  _viewmodel.showOptionalDetailsField
                      ? Container(
                          alignment: Alignment.centerLeft,
                          margin: EdgeInsets.symmetric(horizontal: 10),
                          child: Column(
                            crossAxisAlignment: CrossAxisAlignment.start,
                            children: [
                              SizedBox(
                                height: 10,
                              ),
                              Text(
                                "Detalhes do Serviço(Opcional):",
                                style: TextStyle(
                                  color: Colors.white,
                                  fontSize: 18,
                                  fontWeight: FontWeight.bold,
                                ),
                                textAlign: TextAlign.left,
                              ),
                              SizedBox(
                                height: 10,
                              ),
                              ThemeFormField(
                                "",
                                controller:
                                    _viewmodel.optionalServiceDetailCtrl,
                                keyBoardType: TextInputType.multiline,
                                maxLines: null,
                              ),
                            ],
                          ),
                        )
                      : Container(),
                  SizedBox(
                    height: 50,
                  ),
                  Observer(builder: (BuildContext context) {
                    return _viewmodel.isBusy
                        ? Center(
                            child: CircularProgressIndicator(),
                          )
                        : _viewmodel.repairShop != null &&
                                _viewmodel.manutentionType != null &&
                                _viewmodel.manutentionType !=
                                    ManutentionType.ALL
                            ? ThemeButton(
                                text: "Agendar",
                                action: () {
                                  if (!formKey.currentState.validate()) {
                                    return;
                                  }

                                  _viewmodel.schedule(context);
                                })
                            : Container();
                  }),
                  SizedBox(
                    height: 20,
                  ),
                ],
              ),
            ),
          ),
        ),
      ),
      onWillPop: () async {
        _viewmodel.setMaintenanceType(ManutentionType.ALL);

        return true;
      },
    );
  }
}
