import 'package:flutter/material.dart';
import 'package:flutter_mobx/flutter_mobx.dart';
import 'package:mask_text_input_formatter/mask_text_input_formatter.dart';
import 'package:onyva_mobile/core/widgets/app_bars.dart';
import 'package:onyva_mobile/core/widgets/color_sets.dart';
import 'package:onyva_mobile/core/widgets/terms_and_service_check_box_form_field.dart';
import 'package:onyva_mobile/core/widgets/theme_button.dart';
import 'package:onyva_mobile/core/widgets/theme_form_field.dart';
import 'package:onyva_mobile/validators/signup_page_validator.dart';
import 'package:onyva_mobile/viewmodel/impl/ocr_viewmodel_impl.dart';
import 'package:onyva_mobile/viewmodel/impl/signup_viewmodel_impl.dart';
import 'package:onyva_mobile/viewmodel/ocr_viewmodel.dart';
import 'package:onyva_mobile/viewmodel/signup_viewmodel.dart';

class SignUpPage extends StatefulWidget {
  @override
  SignUpPageState createState() => new SignUpPageState();
}

class SignUpPageState extends State<SignUpPage> {
  final GlobalKey<FormState> formKey = GlobalKey<FormState>();
  final SignUpViewModel viewmodel = new SignUpViewModelImpl();
  final OcrViewModel ocrViewModel = new OcrViewModelImpl();

  @override
  Widget build(BuildContext context) {
    final size = MediaQuery.of(context).size;
    final appBar1 = AppBarCustom(context, "Cadastro");

    return Scaffold(
      resizeToAvoidBottomPadding: true,
      appBar: appBar1,
      body: Container(
        color: ColorSets.gray,
        width: double.infinity,
        height: double.infinity,
        alignment: Alignment.center,
        child: SingleChildScrollView(
          child: Column(
            children: [
              Container(
                margin: EdgeInsets.only(
                  top: 50,
                  bottom: 50,
                ),
                child: Text(
                  'Onyva',
                  style: TextStyle(
                    fontSize: 48,
                    color: ColorSets.lightGray,
                  ),
                ),
              ),
              Container(
                child: Form(
                  key: formKey,
                  child: ListView(
                    shrinkWrap: true,
                    padding:
                        EdgeInsets.symmetric(vertical: 20, horizontal: 16.0),
                    children: [
                      // NOME
                      ThemeFormField(
                        'Nome',
                        keyBoardType: TextInputType.text,
                        validator: SignUpPageValidator.validateName,
                        controller: viewmodel.nomeCtrl,
                      ),

                      SizedBox(height: 15),

                      // CPF
                      ThemeFormField(
                        'Cpf (opcional)',
                        keyBoardType: TextInputType.number,
                        controller: viewmodel.cpfCtrl,
                        formatters: [
                          new MaskTextInputFormatter(
                            mask: '%%%.%%%.%%%-%%',
                            filter: {
                              "%": RegExp(r'[0-9]'),
                            },
                          ),
                        ],
                      ),

                      SizedBox(height: 15),

                      // TELEFONE
                      ThemeFormField(
                        'Telefone (Opcional)',
                        keyBoardType: TextInputType.number,
                        controller: viewmodel.telefoneCtrl,
                        validator: SignUpPageValidator.validateTelefone,
                        formatters: [
                          new MaskTextInputFormatter(
                            mask: '(%%%) %%%%%-%%%%',
                            filter: {
                              "%": RegExp(r'[0-9]'),
                            },
                          ),
                        ],
                      ),
                      SizedBox(height: 15),

                      // EMAIL
                      ThemeFormField(
                        'E-mail',
                        keyBoardType: TextInputType.emailAddress,
                        validator: SignUpPageValidator.validateEmail,
                        controller: viewmodel.emailCtrl,
                      ),
                      SizedBox(height: 15),

                      // SENHA
                      Observer(builder: (BuildContext context) {
                        return ThemeFormField(
                          'Senha',
                          keyBoardType: TextInputType.text,
                          validator: SignUpPageValidator.validatePassword,
                          suffixIcon: IconButton(
                            icon: Icon(
                              viewmodel.showPassword
                                  ? Icons.visibility_off
                                  : Icons.visibility,
                              color: ColorSets.darkGray,
                            ),
                            onPressed: () {
                              viewmodel.toggleShowPassword();
                            },
                          ),
                          obscureText: !viewmodel.showPassword,
                          controller: viewmodel.senhaCtrl,
                        );
                      }),

                      SizedBox(height: 10),

                      // Terms & service
                      TermsAndServiceCheckBoxFormField(
                        initialValue: false,
                        validator: SignUpPageValidator.validadeAgreeTerms,
                        onSaved: (newValue) {
                          viewmodel.updateAgreedTermsOfServiceState(newValue);
                        },
                      ),

                      SizedBox(height: 10),

                      /*Recaptcha(
                        url: 'url-here',
                        siteKey: 'site-key',
                        backgroundColor: ColorSets.gray),

                    SizedBox(height: 10),*/

                      // Botao Cadatrar
                      Observer(builder: (BuildContext context) {
                        return viewmodel.isbusy
                            ? Center(
                                child: CircularProgressIndicator(),
                              )
                            : Row(
                                mainAxisSize: MainAxisSize.min,
                                children: [
                                  Flexible(
                                    fit: FlexFit.tight,
                                    child: ThemeButton(
                                      action: () {
                                        final FormState form =
                                            formKey.currentState;
                                        form.save();

                                        if (!form.validate()) return;

                                        viewmodel.signUp(context);
                                      },
                                      text: 'Cadastrar',
                                    ),
                                  ),
                                ],
                              );
                      }),
                    ],
                  ),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
