import 'package:flutter/material.dart';
import 'package:flutter_mobx/flutter_mobx.dart';
import 'package:intl/intl.dart';
import 'package:mask_text_input_formatter/mask_text_input_formatter.dart';
import 'package:provider/provider.dart';
import 'package:onyva_mobile/core/widgets/app_bars.dart';
import 'package:onyva_mobile/core/widgets/color_sets.dart';
import 'package:onyva_mobile/core/widgets/theme_button.dart';
import 'package:onyva_mobile/core/widgets/theme_form_field.dart';
import 'package:onyva_mobile/models/vehicle.dart';
import 'package:onyva_mobile/state_managers/app_store.dart';
import 'package:onyva_mobile/viewmodel/impl/vehicle_km_update_viewmodel_impl.dart';
import 'package:onyva_mobile/viewmodel/vehicle_km_update_viewmodel.dart';

class VehicleKMUpdatePage extends StatefulWidget {
  final VehicleKmUpdateViewModel _viewModel =
      new VehicleKmUpdateViewModelImpl();

  @override
  _VehicleKMUpdatePageState createState() => _VehicleKMUpdatePageState();
}

class _VehicleKMUpdatePageState extends State<VehicleKMUpdatePage> {
  final GlobalKey<FormState> formKey = GlobalKey<FormState>();

  @override
  Widget build(BuildContext context) {
    AppStore appStore = Provider.of<AppStore>(context);

    return Scaffold(
      resizeToAvoidBottomPadding: true,
      appBar: AppBarCustom(context, "Atualizar Quilometragem"),
      body: Container(
        color: ColorSets.gray,
        width: double.infinity,
        height: double.infinity,
        child: Form(
          key: formKey,
          child: ListView(
            shrinkWrap: true,
            padding: EdgeInsets.symmetric(vertical: 20, horizontal: 16.0),
            children: [
              Container(
                margin: EdgeInsets.only(
                  bottom: 50,
                  top: 50,
                ),
                child: Observer(builder: (BuildContext context) {
                  Vehicle vehicle = appStore.currentVehicle;
                  return Text(
                    vehicle.licensePlate +
                        ' (' +
                        vehicle.modelYear.toString() +
                        ')',
                    style: TextStyle(
                      color: Colors.white,
                      fontSize: 36,
                      decoration: TextDecoration.underline,
                    ),
                    textAlign: TextAlign.center,
                  );
                }),
              ),
              SizedBox(
                height: 25,
              ),
              Text(
                'Atualmente está registrado:',
                style: TextStyle(
                  color: ColorSets.lightGray,
                  fontSize: 20,
                ),
                textAlign: TextAlign.center,
              ),
              Observer(builder: (BuildContext context) {
                Vehicle vehicle = appStore.currentVehicle;
                int mileage = 0;
                if (vehicle != null && vehicle.mileage != null)
                  mileage = vehicle.mileage;
                return Text(
                  mileage.toString() + ' Km',
                  style: TextStyle(
                    color: ColorSets.lightGray,
                    fontSize: 28,
                  ),
                  textAlign: TextAlign.center,
                );
              }),
              SizedBox(
                height: 20,
              ),
              ThemeFormField(
                'Quilometragem do veículo',
                focusNode: new FocusNode(),
                keyBoardType: TextInputType.number,
                controller: widget._viewModel.kmCtrl,
                //controller: viewmodel.nomeCtrl,
              ),
              SizedBox(
                height: 20,
              ),
              Observer(builder: (BuildContext context) {
                return widget._viewModel.isBusy
                    ? Center(
                        child: CircularProgressIndicator(),
                      )
                    : ThemeButton(
                        text: "Atualizar Quilometragem",
                        action: () {
                          final FormState form = formKey.currentState;
                          form.save();
                          if (!form.validate()) return;

                          widget._viewModel.updateKm(context);
                        },
                      );
              }),
            ],
          ),
        ),
      ),
    );
  }
}
