import 'package:firebase_core/firebase_core.dart';
import 'package:firebase_messaging/firebase_messaging.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter_local_notifications/flutter_local_notifications.dart';
import 'package:onyva_mobile/app_routes.dart';
import 'package:onyva_mobile/core/utils/functions.dart';
import 'package:onyva_mobile/models/owner.dart';
import 'package:onyva_mobile/state_managers/app_store.dart';
import 'package:onyva_mobile/viewmodel/loading_viewmodel.dart';
import 'package:provider/provider.dart';

class LoadingViewModelImpl implements LoadingViewModel {
  @override
  void load(BuildContext context) async {
    AppStore appStore = Provider.of<AppStore>(context, listen: false);

    FirebaseApp firebaseApp = await Firebase.initializeApp();
    FirebaseMessaging firebaseMessaging = FirebaseMessaging();

    FlutterLocalNotificationsPlugin flutterLocalNotificationsPlugin =
        Provider.of<FlutterLocalNotificationsPlugin>(context, listen: false);

    const AndroidNotificationDetails androidPlatformChannelSpecifics =
        AndroidNotificationDetails(
      'your channel id',
      'your channel name',
      'your channel description',
      importance: Importance.max,
      priority: Priority.high,
      showWhen: false,
    );
    const NotificationDetails platformChannelSpecifics = NotificationDetails(
      android: androidPlatformChannelSpecifics,
    );

    firebaseMessaging.configure(
      onMessage: (Map<String, dynamic> message) async {
        flutterLocalNotificationsPlugin.show(
          2,
          message['notification']['title'],
          message['notification']['body'],
          platformChannelSpecifics,
          payload: 'item x',
        );
        print("onMessage: $message");
      },
      onLaunch: (Map<String, dynamic> message) async {
        print("onLaunch: $message");
      },
      onResume: (Map<String, dynamic> message) async {
        print("onResume: $message");
      },
    );

    firebaseMessaging.requestNotificationPermissions(
        const IosNotificationSettings(
            sound: true, badge: true, alert: true, provisional: true));
    firebaseMessaging.onIosSettingsRegistered
        .listen((IosNotificationSettings settings) async {
      print("Settings registered: $settings");
    });
    print(await firebaseMessaging.getToken());

    appStore.updateFirebaseMessaging(firebaseMessaging);

    Owner owner = await loadLoggedOwner();
    appStore.updateLoggedOwner(owner);

    if (owner == null) {
      pushNamedAndRemoveUntil(context, AppRoutes.LOGIN_PAGE);
    } else {
      pushNamedAndRemoveUntil(context, AppRoutes.MAIN_PAGE);
    }
  }
}
