import 'package:flutter/cupertino.dart';
import 'package:onyva_mobile/app_routes.dart';
import 'package:onyva_mobile/business/implementation/main_business_impl.dart';
import 'package:onyva_mobile/business/implementation/scheduled_maintenance_business_impl.dart';
import 'package:onyva_mobile/business/main_business.dart';
import 'package:onyva_mobile/business/scheduled_maintenance_business.dart';
import 'package:onyva_mobile/core/utils/functions.dart';
import 'package:onyva_mobile/models/e-pedigree.dart';
import 'package:onyva_mobile/models/enums/scheduled_maintenance_status.dart';
import 'package:onyva_mobile/models/owner.dart';
import 'package:onyva_mobile/models/requested_maintenance.dart';
import 'package:onyva_mobile/models/vehicle.dart';
import 'package:onyva_mobile/state_managers/app_store.dart';
import 'package:onyva_mobile/state_managers/main/main_store.dart';
import 'package:onyva_mobile/viewmodel/main_viewmodel.dart';
import 'package:provider/provider.dart';

class MainViewModelImpl implements MainViewModel {
  MainStore _store = new MainStore();
  MainBusiness _business = new MainBusinessImpl();
  final ScheduledMaintenanceBusiness _scheduledMaintenanceBusiness =
      ScheduledMaintenanceBusinessImpl();

  @override
  Future<void> selectVehicle(BuildContext context, Vehicle vehicle) async {
    AppStore appStore = Provider.of<AppStore>(context, listen: false);

    Vehicle newVehicle =
        appStore.loggedOwner.vehicles.firstWhere((v) => v.id == vehicle.id);

    appStore.updateCurrentVehicle(newVehicle);
  }

  @override
  void goToVehicleRegisterPage(BuildContext context) async {
    await pushNamed(context, AppRoutes.VEHICLE_REGISTER_PAGE);
  }

  @override
  bool get isBusy => _store.isBusy;

  @override
  void goToScheduledMaintenance(
    BuildContext context,
    ManutentionType manutentionType,
  ) async {
    AppStore appStore = Provider.of<AppStore>(context, listen: false);

    Owner owner = appStore.loggedOwner;

    final maintenanceRequestPendingApproval =
        await _scheduledMaintenanceBusiness
            .getScheduledMaintenanceRequestPendingApproval(
      owner.id,
    );

    if (maintenanceRequestPendingApproval != null &&
        maintenanceRequestPendingApproval.status !=
            MaintenanceSchedulingStatus.EX &&
        manutentionType == ManutentionType.SCHEDULED) {
      pushNamedWithArguments(
        context,
        AppRoutes.MAINTENANCE_STATUS_PAGE,
        maintenanceRequestPendingApproval,
      );
    } else {
      var args = {
        "manutentionType": manutentionType,
        "expired": maintenanceRequestPendingApproval != null &&
            maintenanceRequestPendingApproval.status ==
                MaintenanceSchedulingStatus.EX
      };
      pushNamedWithArguments(
        context,
        AppRoutes.SCHEDULED_MAINTENANCE_PAGE,
        args,
      );
    }
  }

  @override
  void goToVehicleKmUpdate(BuildContext context) {
    pushNamed(context, AppRoutes.VEHICLE_KM_UPDATE_PAGE);
  }

  @override
  void goToEPedigree(BuildContext context, List<dynamic> epedigree) async {
    await pushNamedWithArguments(context, AppRoutes.EPEDIGREE_PAGE, epedigree);
  }
}
