import 'package:camera/camera.dart';
import 'package:flutter/material.dart';
import 'package:onyva_mobile/app_routes.dart';
import 'package:onyva_mobile/business/implementation/ocr_business_impl.dart';
import 'package:onyva_mobile/business/ocr_business.dart';
import 'package:onyva_mobile/core/utils/functions.dart';
import 'package:onyva_mobile/models/fipe_vehicle.dart';
import 'package:onyva_mobile/models/owner.dart';
import 'package:onyva_mobile/models/vehicle.dart';
import 'package:onyva_mobile/state_managers/app_store.dart';
import 'package:onyva_mobile/state_managers/ocr/ocr_store.dart';
import 'package:onyva_mobile/view/scan_duty/confirm_car_info.dart';
import 'package:onyva_mobile/viewmodel/ocr_viewmodel.dart';
import 'package:provider/provider.dart';

class OcrViewModelImpl implements OcrViewModel {
  final marcaCtrl = TextEditingController();
  final licensePlateCtrl = TextEditingController();
  final modeloCtrl = TextEditingController();
  final anoFabCtrl = TextEditingController();
  final anoModCtrl = TextEditingController();
  final renavamCtrl = TextEditingController();

  final ocrStore = OcrStore();

  final OcrBusiness _business = OcrBusinessImpl();

  @override
  Future sendImage(BuildContext context, String imagePath) async {
    final response = await this._business.sendImage(imagePath);
    // if (response.modelo != null) {
    Navigator.push(
      context,
      MaterialPageRoute(
        builder: (context) => ConfirmCarInfo(carInfo: response),
      ),
    );
    // }
  }

  @override
  Future<void> saveVehicle(BuildContext context) async {
    ocrStore.updateBusyState(true);
    Owner owner = await this._business.saveVehicle(
        Vehicle(
            licensePlate: licensePlateCtrl.value.text,
            manufactureYear: int.parse(anoFabCtrl.value.text),
            modelYear: int.parse(anoFabCtrl.value.text),
            renavamCode: renavamCtrl.value.text,
            fipeVehicle: FipeVehicle(
              brand: marcaCtrl.value.text,
              model: modeloCtrl.value.text,
            )),
        context);
    AppStore appStore = Provider.of<AppStore>(context, listen: false);
    appStore.updateLoggedOwner(owner);
    saveLoggedOwner(appStore.loggedOwner);

    ocrStore.updateBusyState(false);
    popUntil(context, AppRoutes.VEHICLE_REGISTER_PAGE);
  }

  Future getCamera() async {
    WidgetsFlutterBinding.ensureInitialized();

    final cameras = await availableCameras();

    return cameras.first;
  }

  @override
  bool get isbusy => ocrStore.isBusy;
}
