import 'package:flutter/widgets.dart';
import 'package:flutter_local_notifications/flutter_local_notifications.dart';
import 'package:onyva_mobile/business/implementation/registration_business_impl.dart';
import 'package:onyva_mobile/core/functions/general_information_alert.dart';
import 'package:onyva_mobile/core/functions/generic_error_alert.dart';
import 'package:onyva_mobile/core/utils/functions.dart';
import 'package:onyva_mobile/state_managers/app_store.dart';
import 'package:onyva_mobile/state_managers/signup/signup_store.dart';
import 'package:onyva_mobile/viewmodel/signup_viewmodel.dart';
import 'package:onyva_mobile/models/signup.dart';
import 'package:provider/provider.dart';

class SignUpViewModelImpl implements SignUpViewModel {
  final _nomeCtrl = TextEditingController();
  final _telefoneCtrl = TextEditingController();
  final _cpfCtrl = TextEditingController();
  final _emailCtrl = TextEditingController();
  final _senhaCtrl = TextEditingController();
  final _signUpStore = SignUpStore();
  final _registrationBusiness = RegistrationBusinessImpl();

  @override
  bool get agreedTermsOfService => _signUpStore.agreedTermsOfService;

  @override
  bool get isbusy => _signUpStore.isBusy;

  @override
  bool get showPassword => _signUpStore.showPassword;

  @override
  TextEditingController get cpfCtrl => _cpfCtrl;

  @override
  TextEditingController get emailCtrl => _emailCtrl;

  @override
  TextEditingController get nomeCtrl => _nomeCtrl;

  @override
  TextEditingController get senhaCtrl => _senhaCtrl;

  @override
  TextEditingController get telefoneCtrl => _telefoneCtrl;

  @override
  void toggleShowPassword() {
    _signUpStore.toggleShowPassword();
  }

  @override
  void updateAgreedTermsOfServiceState(bool newState) {
    _signUpStore.updateAgreedTermsOfServiceState(newState);
  }

  @override
  void updateBusyState(bool newState) {
    _signUpStore.updateBusyState(newState);
  }

  @override
  Future<void> signUp(BuildContext context) async {
    Map<String, dynamic> dddAndNumber = extractDDDAndNumber(telefoneCtrl.text);
    int ddd;
    int number;

    if (dddAndNumber != null) {
      ddd = dddAndNumber['ddd'];
      number = dddAndNumber['number'];
    }

    updateBusyState(true);

    AppStore appStore = Provider.of<AppStore>(context, listen: false);

    String firebaseToken = await appStore.firebaseMessaging.getToken();

    SignUp model = new SignUp(
      name: nomeCtrl.text,
      cpf: cpfCtrl.text,
      email: emailCtrl.text,
      phoneDDD: ddd,
      phoneNumber: number,
      password: senhaCtrl.text,
      agreedTermsOfService: agreedTermsOfService,
      firebaseToken: firebaseToken,
    );
    await _registrationBusiness.registerUser(model).then((value) {
      generalInformationAlert(
          context: context,
          title: 'Cadastro de usuário',
          body: Text('Cadastro realizado com sucesso!'),
          okText: 'Ok',
          callbackFunction: (boolean) {
            Navigator.pop(context);
          });
    }).catchError((err) {
      print("ERROR " + err.toString());

      if ((err as String).isNotEmpty) {
        delayAction().then(
          (value) => genericErrorAlert(
            context: context,
            okActionText: 'OK',
            content: Text(err),
          ),
        );
      }
    });
    updateBusyState(false);
  }
}
