import 'package:flutter/cupertino.dart';
import 'package:provider/provider.dart';
import 'package:onyva_mobile/business/implementation/vehicle_km_update_business_impl.dart';
import 'package:onyva_mobile/business/vehicle_km_update_business.dart';
import 'package:onyva_mobile/core/functions/generic_error_alert.dart';
import 'package:onyva_mobile/core/utils/functions.dart';
import 'package:onyva_mobile/state_managers/app_store.dart';
import 'package:onyva_mobile/state_managers/vehicle_km_update/vehicle_km_update_store.dart';
import 'package:onyva_mobile/viewmodel/vehicle_km_update_viewmodel.dart';

class VehicleKmUpdateViewModelImpl implements VehicleKmUpdateViewModel {
  VehicleKmUpdateStore _store = new VehicleKmUpdateStore();
  VehicleKmUpdateBusiness _business = new VehicleKmUpdateBusinessImpl();
  TextEditingController _kmCtrl = new TextEditingController();

  @override
  TextEditingController get kmCtrl => _kmCtrl;

  @override
  bool get isBusy => _store.isBusy;

  @override
  void updateBusyState(bool newState) {
    _store.updateBusyState(newState);
  }

  @override
  int get kms {
    String kmsString =
        _kmCtrl.text != null ? _kmCtrl.text.replaceAll(RegExp(r'\D'), '') : '';
    int kms = int.tryParse(kmsString);

    if (kms == null) {
      return 0;
    } else {
      return kms;
    }
  }

  @override
  void updateKm(BuildContext context) {
    AppStore appStore = Provider.of<AppStore>(context, listen: false);
    updateBusyState(true);
    _business
        .updateKm(appStore.loggedOwner, appStore.currentVehicle, kms)
        .then((newVehicle) {
      appStore.updateCurrentVehicle(newVehicle);
      // pop pagex
    }).catchError((err) {
      print("ERROR " + err.toString());

      if ((err as String).isNotEmpty) {
        delayAction().then(
          (value) => genericErrorAlert(
            context: context,
            okActionText: 'OK',
            content: Text(err),
          ),
        );
      }
    }).whenComplete(() {
      updateBusyState(false);
    });
  }
}
