import 'package:flutter/cupertino.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:mockito/mockito.dart';
import 'package:onyva_mobile/core/utils/functions.dart';
import 'package:onyva_mobile/models/owner.dart';
import 'package:onyva_mobile/models/requested_maintenance.dart';
import 'package:onyva_mobile/models/vehicle.dart';

//class MockBuildContext extends Mock implements BuildContext {}

//MockBuildContext buildContext = MockBuildContext();

void main() {
  //popUntilTest();
  saveLoggedOwnerTest();
  loadLoggedOwnerTest();
  mergeVehicleListTest();
  mergeRequestedMaintenanceListTest();
  extractDDDAndNumberTest();
  getNameOfManutentionTypeTest();
}

/*void popUntilTest() {
  test('context null dispara exceção', () {
    try {
      popUntil(null, "");
      expect(false, true);
    } catch (exc) {
      expect(true, true);
    }
  });

  test('route null dispara exceção', () {
    try {
      popUntil(buildContext, null);
      expect(false, true);
    } catch (exc) {
      expect(true, true, reason: exc);
    }
  });
}*/

void saveLoggedOwnerTest() {
  test('salvar owner logado(null) nao ocorre exceções', () {
    try {
      saveLoggedOwner(null);
      expect(true, true);
    } catch (exc) {
      expect(false, true);
    }
  });

  test('salvar owner logado(owner obj) nao ocorre exceções', () {
    try {
      saveLoggedOwner(Owner.fromJson({
        "id": "123",
      }));
      expect(true, true);
    } catch (exc) {
      expect(false, true);
    }
  });
}

void loadLoggedOwnerTest() {
  test('carregar owner logado nao ocorre exceções', () async {
    try {
      saveLoggedOwner(Owner.fromJson({
        'id': 'test',
      }));
      Owner o = await loadLoggedOwner();
      expect(o.id, 'test');
    } catch (exc) {
      expect(false, true);
    }
  });
}

void mergeVehicleListTest() {
  Vehicle v1 = Vehicle(id: '1', mileage: 5);
  Vehicle v2 = Vehicle(id: '2', mileage: 8);

  Vehicle v3 = Vehicle(id: '1', mileage: 3);
  Vehicle v4 = Vehicle(id: '3', mileage: 9);

  List<Vehicle> rms1 = [v1, v2];

  List<Vehicle> rms2 = [v3, v4];

  test('merge de listas de veículos null retorna null', () {
    List<Vehicle> result = mergeVehicleList(null, null);
    expect(result, null);
  });

  test(
      'merge de lista de veículos 1 null e 2 preenchida retorna lista de veículos 2',
      () {
    List<Vehicle> result = mergeVehicleList(null, rms2);
    expect(result, rms2);
  });

  test(
      'merge de lista de veículos 1 preenchida e 2 null retorna lista de veículos 1',
      () {
    List<Vehicle> result = mergeVehicleList(rms1, null);
    expect(result, rms1);
  });

  test('merge de listas de veículos preenchidas', () {
    List<Vehicle> result = mergeVehicleList(rms1, rms2);
    expect(
        result.length == 2 &&
            result[0].id == '1' &&
            result[0].mileage == 3 &&
            result[1].id == '3' &&
            result[1].mileage == 9,
        true);
  });
}

void mergeRequestedMaintenanceListTest() {
  RequestedMaintenance r1 = RequestedMaintenance(id: '1', ownerId: '5');
  RequestedMaintenance r2 = RequestedMaintenance(id: '2', ownerId: '8');

  RequestedMaintenance r3 = RequestedMaintenance(id: '1', ownerId: '3');
  RequestedMaintenance r4 = RequestedMaintenance(id: '3', ownerId: '9');

  List<RequestedMaintenance> rms1 = [r1, r2];

  List<RequestedMaintenance> rms2 = [r3, r4];

  test('merge de listas de manutencao null retorna null', () {
    List<RequestedMaintenance> result =
        mergeRequestedMaintenanceList(null, null);
    expect(result, null);
  });

  test(
      'merge de lista de manutencao 1 null e 2 preenchida retorna lista de manutencao 2',
      () {
    List<RequestedMaintenance> result =
        mergeRequestedMaintenanceList(null, rms2);
    expect(result, rms2);
  });

  test(
      'merge de lista de manutencao 1 preenchida e 2 null retorna lista de manutencao 1',
      () {
    List<RequestedMaintenance> result =
        mergeRequestedMaintenanceList(rms1, null);
    expect(result, rms1);
  });

  test('merge de listas de manutencao preenchidas', () {
    List<RequestedMaintenance> result =
        mergeRequestedMaintenanceList(rms1, rms2);
    expect(
        result.length == 2 &&
            result[0].id == '1' &&
            result[0].ownerId == '3' &&
            result[1].id == '3' &&
            result[1].ownerId == '9',
        true);
  });
}

void extractDDDAndNumberTest() {
  test('extraindo de numero null dispara exceção', () {
    try {
      extractDDDAndNumber(null);
      expect(false, true);
    } catch (exc) {
      expect(true, true, reason: exc.toString());
    }
  });

  test('extraindo de numero incorreto retorna null', () {
    Map result = extractDDDAndNumber("51d515151515");
    expect(result, null);
  });

  test('extraindo de numero correto retorna corretamente ddd e number', () {
    Map result = extractDDDAndNumber("999 51515151");
    expect(result, {
      'ddd': 999,
      'number': 51515151,
    });
  });

  test('extraindo de numero correto retorna corretamente ddd e number', () {
    Map result = extractDDDAndNumber("(1)53151-5151");
    expect(result, {
      'ddd': 1,
      'number': 531515151,
    });
  });
}

void getNameOfManutentionTypeTest() {
  test('nome da manutencao preventiva', () {
    String result = getNameOfManutentionType(ManutentionType.PREVENTIVE);
    expect(result, "Manutenção Preventiva");
  });

  test('nome da manutencao programada', () {
    String result = getNameOfManutentionType(ManutentionType.SCHEDULED);
    expect(result, "Manutenção Programada");
  });

  test('nome da manutencao urgente', () {
    String result = getNameOfManutentionType(ManutentionType.URGENT);
    expect(result, "Manutenção Urgente");
  });

  test('nome da manutencao all', () {
    String result = getNameOfManutentionType(ManutentionType.ALL);
    expect(result, "Manutenção");
  });

  test('nome da manutencao null', () {
    String result = getNameOfManutentionType(null);
    expect(result, "");
  });
}
