import 'package:flutter_test/flutter_test.dart';
import 'package:onyva_mobile/validators/signup_page_validator.dart';

void main() {
  validadeAgreeTermsTest();
  validateNameTest();
  validatePasswordTest();
  validateTelefoneTest();
  validateEmailTest();
}

void validadeAgreeTermsTest() {
  test('nao aceitar termos retorna erro', () {
    String result = SignUpPageValidator.validadeAgreeTerms(false);
    expect(result.isNotEmpty, true);
  });

  test('aceitar termos retorna null', () {
    String result = SignUpPageValidator.validadeAgreeTerms(true);
    expect(result, null);
  });
}

void validateNameTest() {
  test('nome vazio retorna erro', () {
    String result = SignUpPageValidator.validateName("");
    expect(result.isNotEmpty, true);
  });

  test('nome em branco retorna erro', () {
    String result = SignUpPageValidator.validatePassword(" ");
    expect(result.isNotEmpty, true);
  });

  test('nome preenchido retorna null', () {
    String result = SignUpPageValidator.validatePassword("teste test");
    expect(result, null);
  });
}

void validatePasswordTest() {
  test('senha vazia retorna erro', () {
    String result = SignUpPageValidator.validatePassword("");
    expect(result.isNotEmpty, true);
  });

  test('senha invalida(espaço em branco) retorna erro', () {
    String result = SignUpPageValidator.validatePassword(" ");
    expect(result.isNotEmpty, true);
  });

  test('senha invalida(menos que 8 caracteres) retorna erro', () {
    String result = SignUpPageValidator.validatePassword("5293&%");
    expect(result.isNotEmpty, true);
  });

  test('senha valida retorna null', () {
    String result = SignUpPageValidator.validatePassword("re&%er90ti");
    expect(result, null);
  });

  test('senha valida retorna null', () {
    String result = SignUpPageValidator.validatePassword("R3g905!!!");
    expect(result, null);
  });
}

void validateTelefoneTest() {
  test('telefone vazio retorna null', () {
    String result = SignUpPageValidator.validateTelefone("");
    expect(result, null);
  });

  test('telefone valido retorna null', () {
    String result = SignUpPageValidator.validateTelefone("99 99988-7766");
    expect(result, null);
  });

  test('telefone valido retorna null', () {
    String result = SignUpPageValidator.validateTelefone("99999887766");
    expect(result, null);
  });

  test('telefone valido retorna null', () {
    String result = SignUpPageValidator.validateTelefone("9999887766");
    expect(result, null);
  });

  test('telefone valido retorna null', () {
    String result = SignUpPageValidator.validateTelefone("1 59349844");
    expect(result, null);
  });

  test('telefone valido retorna null', () {
    String result = SignUpPageValidator.validateTelefone("(1) 913222222");
    expect(result, null);
  });

  test('telefone valido retorna null', () {
    String result = SignUpPageValidator.validateTelefone("(99)99988-7766");
    expect(result, null);
  });

  test('telefone valido retorna null', () {
    String result = SignUpPageValidator.validateTelefone("(9)99988-7766");
    expect(result, null);
  });

  test('telefone invalido retorna erro', () {
    String result = SignUpPageValidator.validateTelefone("zzzzzz");
    expect(result.isNotEmpty, true);
  });

  test('telefone invalido retorna erro', () {
    String result = SignUpPageValidator.validateTelefone("42390");
    expect(result.isNotEmpty, true);
  });

  test('telefone invalido retorna erro', () {
    String result = SignUpPageValidator.validateTelefone("((32)34902434");
    expect(result.isNotEmpty, true);
  });

  test('telefone invalido retorna erro', () {
    String result = SignUpPageValidator.validateTelefone("(32)67868878-4344");
    expect(result.isNotEmpty, true);
  });
}

void validateEmailTest() {
  test('email vazio retorna erro', () {
    String result = SignUpPageValidator.validateEmail("");
    expect(result.isNotEmpty, true);
  });

  test('email invalido(espaço em branco) retorna erro', () {
    String result = SignUpPageValidator.validateEmail(" ");
    expect(result.isNotEmpty, true);
  });

  test('email invalido(dominio invalido) retorna erro', () {
    String result = SignUpPageValidator.validateEmail("test@test.");
    expect(result.isNotEmpty, true);
  });

  test('email invalido(dominio invalido) retorna erro', () {
    String result = SignUpPageValidator.validateEmail("test@.com");
    expect(result.isNotEmpty, true);
  });

  test('email invalido(sem dominio) retorna erro', () {
    String result = SignUpPageValidator.validateEmail("test");
    expect(result.isNotEmpty, true);
  });

  test('email valido retorna null', () {
    String result = SignUpPageValidator.validateEmail("test@tst.tst");
    expect(result, null);
  });

  test('email valido retorna null', () {
    String result = SignUpPageValidator.validateEmail("test@gmail.com");
    expect(result, null);
  });
}
